const CasePersonForm = {
  name: 'CasePersonForm',
  props: {
    // 绑定的数组
    value: {
      type: Array,
      default () {
        return []
      }
    },
    // 是否禁用
    disabled: {
      type: Boolean,
      default () {
        return false
      }
    },
    // 下拉选项
    options: {
      type: Object,
      default () {
        return {}
      }
    },
    // 当事人类型
    type: {
      type: String,
      default: '0'
    }
  },
  template: `
    <div class="case-person--form">
       <div v-for="(person, index) in value" :key="person.pid" :name="'Person_' + person.pid" class="case-person--single__wrapper">
          <span :id="'casePerson_' + person.pid" class="target_link" />
          <div class="case-person--single__header">
            <div class="case-person--single__title">{{ headerTitle(index) }}</div>
            <div v-if="!disabled" class="case-person--single__options">
             <!--      设为常用           -->
             <el-button v-if="!disabled && person.readonly && visible('setUsuallyPerson')" size="mini"
                           type="primary" @click.stop="setCommonUseCasePerson(person)"
                >设为常用
              </el-button>
              <!--                 删除-->
              <el-button
                v-if="person.readonly && !disabled"
                type="danger"
                size="small"
                @click.stop="casePersonDelete(person, index)"
               >删除</el-button>
               <!--                 编辑-->
               <el-button
                  v-if="person.readonly && !disabled"
                  type="primary"
                  size="small"
                  @click.stop="casePersonEdit(person, index)"
                >编辑
               </el-button>
            </div>
          </div>
          <div class="case-person--single__form">
            <el-form
                :class="{ 'el-form--disabled': person.readonly }"
                :hide-required-asterisk="person.readonly"
                label-position="right"
                :disabled="disabled || person.readonly"
                label-width="auto"
                :model="person"
                :ref="person.pid"
            >
             <el-row v-if="type !== '17'">
<!--             当事人类型-->
             <el-col :span="8" v-if="visible('peopleType')">
                <el-form-item
                  label="当事人类型："
                  prop="peopleType"
                  :rules="[
                    { required: requiredRules[type].peopleType || false, message: '请选择当事人类型', trigger: 'blur' }
                  ]"
                >

                   <el-select
                       v-if="!person.readonly"
                       @change="clearFormAndValidate(person)"
                       v-model="person.peopleType"
                     >
                        <el-option value="0" label="自然人"></el-option>
                        <el-option value="1" label="法人"></el-option>
                        <el-option value="2" label="非法人组织"></el-option>
                   </el-select>
                   <div class="readonly-text-field" v-else>{{ peopleTypeMap[person.peopleType] }}</div>
                </el-form-item>
               </el-col>
<!--               当事人类型---申请人类型--能力认定-->
             <el-col :span="8" v-if="visible('applyPersonTypePowerIdentify')">
                <el-form-item
                  label="申请人类型："
                  prop="applyPersonType"
                  :rules="[
                    { required: requiredRules[type].applyPersonType || false, message: '请选择申请人类型' , trigger: 'blur' }
                    ]"
                  >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-applyPersonType"
                    v-model="person.applyPersonType"
                    style="width: 100%"
                    placeholder="请选择申请人类型"
                    @change="setLabelBaseValue($event, options.applyPersonTypePowerIdentify, person, 'value', { 'applyPersonTypeName': 'label' }, 'applyPersonType')"
                  >
                    <el-option
                      v-for="(item, index) in options.applyPersonTypePowerIdentify"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.applyPersonTypeName || '-' }}
                  </div>
                </el-form-item>
               </el-col>
<!--               当事人类型--申请人类型--物品担保权-->
             <el-col :span="8" v-if="visible('applyPersonTypeItem')">
                <el-form-item
                  label="申请人类型："
                  prop="applyPersonType"
                  :rules="[
                    { required: requiredRules[type].applyPersonType || false, message: '请选择申请人类型' , trigger: 'blur' }
                    ]"
                  >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-applyPersonType"
                    v-model="person.applyPersonType"
                    style="width: 100%"
                    placeholder="请选择申请人类型"
                    @change="setLabelBaseValue($event, options.applyPersonTypeItem, person, 'value', { 'applyPersonTypeName': 'label' }, 'applyPersonType')"
                  >
                    <el-option
                      v-for="(item, index) in options.applyPersonTypeItem"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.applyPersonTypeName || '-' }}
                  </div>
                </el-form-item>
               </el-col>
<!--               当事人类型--申请人类型-- 自赔-->
             <el-col :span="8" v-if="visible('applyPersonTypeFromCourt')">
                <el-form-item
                  label="申请人类型："
                  prop="applyPersonType"
                  :rules="[
                    { required: requiredRules[type].applyPersonType || false, message: '请选择申请人类型' , trigger: 'blur' }
                    ]"
                  >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-applyPersonType"
                    v-model="person.applyPersonType"
                    style="width: 100%"
                    placeholder="请选择申请人类型"
                    @change="setLabelBaseValue($event, options.applyPersonTypeFromCourt, person, 'value', { 'applyPersonTypeName': 'label' }, 'applyPersonType')"
                  >
                    <el-option
                      v-for="(item, index) in options.applyPersonTypeFromCourt"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.applyPersonTypeName || '-' }}
                  </div>
                </el-form-item>
               </el-col>
<!--               当事人---申请事项-->
             <el-col :span="8" v-if="visible('applyMatterPowerIdentify')">
                <el-form-item
                  label="申请事项："
                  prop="applyMatter"
                  :rules="[
                    { required: requiredRules[type].applyMatter || false, message: '请选择申请事项' , trigger: 'blur' }
                    ]"
                  >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-applyMatter"
                    v-model="person.applyMatter"
                    style="width: 100%"
                    placeholder="请选择申请事项"
                    @change="setLabelBaseValue($event, options.applyMatterPowerIdentify, person, 'value', { 'applyMatterName': 'label' }, 'applyMatter')"
                  >
                    <el-option
                      v-for="(item, index) in options.applyMatterPowerIdentify"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.applyMatterName || '-' }}
                  </div>
                </el-form-item>
               </el-col>
<!--               当事人--起诉类型 -->
             <el-col :span="8" v-if="visible('prosecutionType')">
                <el-form-item
                  label="起诉类型："
                  prop="prosecutionType"
                  :rules="[
                    { required: requiredRules[type].prosecutionType || false, message: '请选择起诉类型' , trigger: 'blur' }
                    ]"
                  >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-prosecutionType"
                    v-model="person.prosecutionType"
                    style="width: 100%"
                    placeholder="请选择起诉类型"
                    @change="setLabelBaseValue($event, options.prosecutionType, person, 'value', { 'prosecutionTypeName': 'label' }, 'prosecutionType')"
                  >
                    <el-option
                      v-for="(item, index) in options.prosecutionType"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.prosecutionTypeName || '-' }}
                  </div>
                </el-form-item>
               </el-col>
<!--               留白占位-->
             <el-col :span="8" v-if="visible('blankPlaceholder')">
               <div style="color: transparent;user-select: none;-webkit-user-select: none;-moz-user-select: none;-ms-user-select: none">1</div>
             </el-col>
<!--               代理人类型-->
             <el-col :span="8" v-if="visible('agentType')">
                 <el-form-item
                  label="代理人类型："
                  prop="agentType"
                  :rules="[
                    { required: requiredRules[type].agentType || false, message: '请选择代理人类型', trigger: 'blur' }
                  ]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-agent_type"
                    v-model="person.agentType"
                    style="width: 100%"
                    :clearable="!requiredRules[type].agentType"
                    placeholder="请选择代理人类型"
                    @change="setLabelBaseValue($event, options.agentType, person, 'value', { 'agentTypeName': 'label' }, 'agentType', 'clearLawInfo')"
                  >
                    <el-option
                      v-for="(item, index) in options.agentType"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.agentTypeName || '-' }}
                  </div>
                </el-form-item>
               </el-col>
<!--               被代理人-->
             <el-col :span="8" v-if="visible('belongToPlantiffAgent')">
                 <el-form-item
                  label="被代理人："
                  prop="belongToPlantiff"
                  :rules="[
                    { required: requiredRules[type].belongToPlantiff || false, message: '请选择被代理人', trigger: 'blur' }
                  ]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-belongToPlantiff"
                    v-model="person.belongToPlantiff"
                    style="width: 100%"
                     multiple
                    :clearable="!requiredRules[type].belongToPlantiff"
                    placeholder="请选择被代理人"
                    @change="setLabelBaseValue($event, getPlaintiffPersons, person, 'pid', { 'part_name': 'name', 'part_number': 'pid' }, 'belongToPlantiff')"
                  >
                    <el-option
                      v-for="(item, index) in getPlaintiffPersons"
                      :key="index"
                      v-if="isOverSelected(item)"
                      :value="item.pid"
                      :label="item.name"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.part_name || '-' }}
                  </div>
                </el-form-item>
               </el-col>
<!--               证人-有利方-->
             <el-col :span="8" v-if="visible('belongToPlantiffWitness')">
                <el-form-item
                  label="有利方："
                  prop="belongToPlantiff"
                  :rules="[
                    { required: requiredRules[type].belongToPlantiff || false, message: '请选择证人有利方', trigger: 'blur' }
                  ]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-belongToPlantiff"
                    v-model="person.belongToPlantiff"
                    style="width: 100%"
                    multiple
                    :clearable="!requiredRules[type].belongToPlantiff"
                    placeholder="请选择证人有利方"
                    @change="setLabelBaseValue($event, getPlaintiffPersons, person, 'pid', { 'part_name': 'name', 'part_number': 'pid' }, 'belongToPlantiff')"
                  >
                    <el-option
                      v-for="(item, index) in getPlaintiffPersons"
                      :key="index"
                      v-if="isOverSelected(item)"
                      :value="item.pid"
                      :label="item.name"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.part_name || '-' }}
                  </div>
                </el-form-item>
               </el-col>
<!--               证人-是否出庭作证-->
              <el-col :span="8" v-if="visible('inCourt')">
                <el-form-item
                  label="是否出庭作证："
                  prop="inCourt"
                  :rules="[
                    { required: requiredRules[type].inCourt || false, message: '请选择证人是否出庭作证', trigger: 'blur' }
                  ]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-inCourt"
                    v-model="person.inCourt"
                    style="width: 100%"
                    :clearable="!requiredRules[type].inCourt"
                    placeholder="请选择证人是否出庭作证"
                    @change="setLabelBaseValue($event, options.inCourt, person, 'value', { 'inCourtName': 'label' }, 'inCourt')"
                  >
                    <el-option
                      v-for="(item, index) in options.inCourt"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.inCourtName || '-' }}
                  </div>
                </el-form-item>
               </el-col>
<!--               导入-->
             <el-col :span="8" v-if="visible('import') && !person.readonly">
                 <div style="text-align: right">
                      <el-button
                          type="primary"
                          class="button-add--person"
                          @click.stop="handleImport(person)"
                      >
                        <img :src="plusIcon" class="btn-plus" alt="添加图标">
                        {{ '导入' + importBtnName(person) }}
                      </el-button>
                 </div>
               </el-col>
             </el-row>
             <el-row v-if="person.peopleType !== '1' && person.peopleType !== '2'">
<!--             姓名-->
             <el-col :span="8" v-if="visible('name')">
                 <el-form-item
                    label="姓名："
                    prop="name"
                    :rules="[
                     { required: requiredRules[type].name || false, message: getPlaceHolder('输入', '', '姓名'), trigger: 'blur' },
                     { validator: validateRuleName, trigger: 'blur' }
                    ]"
                  >
                        <el-input
                          v-if="!person.readonly"
                          v-model="person.name"
                          @input="limitWords('name', person, 'name')"
                          :placeholder="getPlaceHolder('输入', '', '姓名')"
                          maxlength="16"
                          show-word-limit
                        ></el-input>
                        <div v-else class="readonly-text-field">
                          {{ person.name || '-' }}
                        </div>
                      </el-form-item>
                  </el-col>
<!--              手机号 -->
             <el-col :span="8" v-if="visible('mobilePhone')">
                    <el-form-item
                      label="手机号码："
                      prop="mobilePhone"
                      :rules="[
                        { required: requiredRules[type].mobilePhone || false, message: '请输入手机号码', trigger: 'blur' },
                        { validator: validateMobilePhone, trigger: 'blur' }
                      ]"
                     >
                    <el-input
                      v-if="!person.readonly"
                      v-model.trim="person.mobilePhone"
                      :placeholder="getPlaceHolder('输入', '', '手机号码')"
                      maxlength="11"
                      show-word-limit
                      @input="limitWords('digit', person, 'mobilePhone')"
                    />
                    <div v-else class="readonly-text-field">
                      {{ person.mobilePhone || '-' }}
                    </div>
                  </el-form-item>
                </el-col>
<!--                性别-->
             <el-col :span="8" v-if="visible('sex')">
               <el-form-item
                  label="性别："
                  prop="sex"
                  :rules="[
                    { required: requiredRules[type].sex || false, message: getPlaceHolder('选择', '', '性别') , trigger: 'blur' }
                    ]"
                  >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-person__sex"
                    v-model="person.sex"
                    style="width: 100%"
                    :placeholder="getPlaceHolder('选择', '', '性别')"
                    @change="setLabelBaseValue($event, options.sex, person, 'value', { 'sexName': 'label' }, 'sex')"
                  >
                    <el-option
                      v-for="(item, index) in options.sex"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ { '0': '男', '1': '女', '2': '其他' }[person.sex] || '-' }}
                  </div>
                </el-form-item>
             </el-col>
<!--             证件类型 -->
             <el-col :span="8" v-if="visible('cardType')">
                 <el-form-item
                  label="证件类型："
                  prop="cardType"
                  :rules="[
                    { required: requiredRules[type].cardType || false, message: '请选择证件类型', trigger: 'blur' }
                  ]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-card__type"
                    v-model="person.cardType"
                    style="width: 100%"
                    :clearable="!requiredRules[type].cardType"
                    placeholder="请选择证件类型"
                    @change="setLabelBaseValue($event, options.cardType, person, 'value', { 'cardTypeName': 'label' }, 'cardType', 'clearCardNumber')"
                  >
                    <el-option
                      v-for="(item, index) in options.cardType"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.cardTypeName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--             证件号-->
             <el-col :span="8" v-if="visible('cardNumber')">
                <el-form-item
                  label="证件号码："
                  prop="cardNumber"
                  :rules="[
                    { required: requiredRules[type].cardNumber || false, message: '请输入证件号码', trigger: 'blur' },
                    { validator: validateCardNumByType(person), trigger: 'blur' },
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model.trim="person.cardNumber"
                    :disabled="!isDef(person.cardType)"
                    placeholder="请输入证件号码"
                    maxlength="50"
                    show-word-limit
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.cardNumber || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--             民族-->
             <el-col :span="8" v-if="visible('nation')">
                <el-form-item
                  label="民族："
                  prop="nation"
                  :rules="[
                    { required: requiredRules[type].nation || false, message: '请选择民族', trigger: 'blur' }
                  ]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-nation__name"
                    v-model="person.nation"
                    style="width: 100%"
                    placeholder="请选择民族"
                    :clearable="!requiredRules[type].mobilePhone"
                    @change="setLabelBaseValue($event, options.nation, person, 'value', { 'nationName': 'label' }, 'nation')"
                  >
                    <el-option
                      v-for="(item, index) in options.nation"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.nationName || '-' }}
                  </div>
                </el-form-item>
            </el-col>
<!--          出生日期  -->
              <el-col :span="8" v-if="visible('bornDate')">
                <el-form-item
                  label="出生日期："
                  prop="bornDate"
                  :rules="[
                    { required: requiredRules[type].bornDate || false, message: '请选择出生日期', trigger: 'blur' }
                  ]"
                >
                  <el-date-picker
                    v-if="!person.readonly"
                    v-model="person.bornDate"
                    style="width: 100%"
                    :clearable="!requiredRules[type].bornDate"
                    default-value="1990-01-01"
                    placeholder="请选择出生日期"
                    value-format="yyyy-MM-dd"
                    format="yyyy-MM-dd"
                    @change="setAgeByDate(person)"
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.bornDate || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              年龄-->
              <el-col :span="8" v-if="visible('age')">
                <el-form-item
                  label="年龄："
                  prop="age"
                  :rules="[ { required: requiredRules[type].age || false, message: '请选择出生日期', trigger: 'blur' } ]"
                >
                  <el-input
                     v-if="!person.readonly"
                     v-model="person.age"
                     maxlength="3"
                     show-word-limit
                     disabled
                     placeholder="请选择出生日期"
                  />
                  <div v-else class="readonly-text-field">{{ person.age || '-' }}</div>
                </el-form-item>
              </el-col>
<!--              职业-->
              <el-col :span="8" v-if="visible('occupation')">
                <el-form-item
                  label="职业："
                  prop="occupation"
                  :rules="[ { required: requiredRules[type].occupation || false, message: '请选择职业', trigger: 'blur' } ]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-occupation__name"
                    v-model="person.occupation"
                    style="width: 100%"
                    :clearable="!requiredRules[type].occupation"
                    placeholder="请选择职业"
                    @change="setLabelBaseValue($event, options.occupation, person, 'value', { 'occupationName': 'label' }, 'occupation')"
                  >
                    <el-option
                      v-for="(item, index) in options.occupation"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.occupationName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              工作单位-->
              <el-col :span="8" v-if="visible('unitName')">
                <el-form-item
                  label="工作单位："
                  prop="unitName"
                  :rules="[ { required: requiredRules[type].unitName || false, message: '请输入工作单位', trigger: 'blur' } ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model.trim="person.unitName"
                    placeholder="请输入工作单位"
                    maxlength="50"
                    show-word-limit
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.unitName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              固定电话-->
              <el-col :span="8" v-if="visible('phone')">
                <el-form-item
                   label="固定电话："
                   prop="phone"
                  :rules="[ { required: requiredRules[type].phone || false, message: '请输入固定电话', trigger: 'blur' } ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model="person.phone"
                    placeholder="请输入固定电话"
                    maxlength="50"
                    show-word-limit
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.phone || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              地址类型-->
              <el-col :span="24" v-if="!person.readonly && visible('addressType')">
                <el-form-item
                  label="地址类型："
                  prop="addressType"
                  :rules="[
                    { required: requiredRules[type].addressType || false, message: '请选择地址类型' }
                  ]"
                >
                  <el-radio-group v-model="person.addressType">
                        <el-radio label="0">经常居住地</el-radio>
                        <el-radio label="1">户籍所在地</el-radio>
                      </el-radio-group>
                </el-form-item>
              </el-col>
<!--              住所地-->
              <el-col :span="8" v-if="visible('addressAreaCode')">
                <el-form-item
                  label="居住地："
                  prop="addressAreaCode"
                  :rules="[
                    { required: requiredRules[type].addressAreaCode || false, message: '请选择居住地', trigger: 'blur' }
                  ]"
                >
                  <el-cascader
                    v-if="!person.readonly"
                    ref="provienceCityAres"
                    v-model="person.addressAreaCode"
                    style="flex: 1"
                    :options="options.provience"
                    :show-all-levels="true"
                    :props="{
                      expandTrigger: 'hover',
                      value: 'id',
                      label : 'name',
                      children: 'childList',
                      emitPath: false
                    }"
                    clearable
                    @change="provienceCityAresChange($event,'provienceCityAres',person, 'agentAddressInput', 'addressAreaCode')"
                  />
                  <div v-else class="readonly-text-field">{{ person.addressAreaCodeName || '-' }}</div>
                </el-form-item>
              </el-col>
<!--              详细地址-->
              <el-col :span="16" v-if="visible('applicantDetailedAddress')">
                <el-form-item
                  label="详细地址："
                  prop="applicantDetailedAddress"
                  :rules="[
                    { required: requiredRules[type].applicantDetailedAddress || false, message: '请输入详细地址', trigger: 'blur' },
                    { validator: validateAddressCredit('provienceCityAres', person), trigger: 'blur' }
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    ref="agentAddressInput"
                    v-model.trim="person.applicantDetailedAddress"
                    maxlength="100"
                    show-word-limit
                    placeholder="请输入详细地址（街道、楼牌号等）"
                  />
                  <div v-else class="readonly-text-field">{{ person.applicantDetailedAddress || '-' }}</div>
                </el-form-item>
              </el-col>
<!--              代理人-->
              <template v-if="['0', '1', 0, 1].includes(person.agentType)">
               <el-col span="8" >
                 <el-form-item
                    label="执业证号："
                    prop="licenseNumber"
                    :rules="[ { required: requiredRules[type].licenseNumber || false, message: '请输入执业证号', trigger: 'blur' } ]"
                  >
                    <el-input v-if="!person.readonly" v-model.trim="person.licenseNumber" placeholder="请输入执业证号"
                              maxlength="30" show-word-limit
                    ></el-input>
                    <div v-else class="readonly-text-field">
                      {{ person.licenseNumber || '-' }}
                    </div>
                  </el-form-item>
                </el-col>
                <el-col span="8">
                  <el-form-item
                    label="律所名称："
                    prop="registeredAddress"
                    :rules="[ { required: requiredRules[type].registeredAddress || false, message: '请输入律所名称', trigger: 'blur' } ]"
                  >
                    <el-input v-if="!person.readonly" v-model.trim="person.registeredAddress" placeholder="请输入律所名称"
                              maxlength="100" show-word-limit
                    ></el-input>
                    <div v-else class="readonly-text-field">
                      {{ person.registeredAddress || '-' }}
                    </div>
                  </el-form-item>
                </el-col>
              </template>
          </el-row>
          <el-row v-else>
<!--               单位名称-->
              <el-col :span="8" v-if="visible('name')">
                <el-form-item
                  label="单位名称："
                  prop="name"
                  :rules="[{ required: requiredRules[type].name || false, message: '请输入单位名称'}]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model.trim="person.name"
                    placeholder="请输入单位名称"
                    maxlength="100"
                    show-word-limit
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.name || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              查询公司真实信息-->
              <el-col v-if="visible('business_info')" v-show="!person.readonly" :span="8">
                <el-form-item label-width="0">
                  <span style="margin-left: 23px">查询公司真实信息：  <a class="link_blank" href="http://www.gsxt.gov.cn/corp-query-homepage.html" target="_blank">国家企业信用信息公示系统</a></span>
                </el-form-item>
              </el-col>
<!--              单位性质-->
              <el-col :span="8" v-if="visible('unitNature')">
                <el-form-item
                 label="单位性质："
                 prop="unitNature"
                 :rules="[{ required: requiredRules[type].unitNature || false, message: '请选择单位性质', trigger: 'blur' }]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-unit__nature"
                    v-model="person.unitNature"
                    style="width: 100%"
                    :clearable="!requiredRules[type].unitNature"
                    placeholder="请选择单位性质"
                    @change="setLabelBaseValue($event, options.unitNature, person, 'value', { 'unitNatureName': 'label' }, 'unitNature')"
                  >
                    <el-option
                      v-for="(item, index) in options.unitNature"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.unitNatureName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              证照类型-->
              <el-col :span="8" v-if="visible('licenseType')">
                <el-form-item
                  label="证照类型："
                  prop="licenseType"
                  :rules="[
                    { required: requiredRules[type].licenseType || false, message: '请选择证照类型', trigger: 'blur' }
                  ]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-license__type"
                    v-model="person.licenseType"
                    :clearable="!requiredRules[type].licenseType"
                    style="width: 100%"
                    placeholder="请选择证照类型"
                    @change="setLabelBaseValue($event, options.licenseType, person, 'value', { 'licenseTypeName': 'label' }, 'licenseType', 'clearLicenseNumber')"
                  >
                    <el-option
                      v-for="(item, index) in options.licenseType"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.licenseTypeName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              证照号码-->
              <el-col :span="8" v-if="visible('licenseNumber')">
                <el-form-item
                  label="证照号码："
                  prop="licenseNumber"
                  :rules="[
                    { required: requiredRules[type].licenseNumber || false, message: '请输入证照号码', trigger: 'blur' },
                    { validator: validateLicenseNumberByType(person), trigger: 'blur' },
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model.trim="person.licenseNumber"
                    :disabled="!isDef(person.licenseType)"
                    placeholder="请输入证照号码"
                    maxlength="50"
                    show-word-limit
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.licenseNumber || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              赔偿义务机关--类型-->
              <el-col :span="24" v-if="visible('obligationOrganType')">
                 <el-form-item
                  label="赔偿义务机关类型："
                  prop="obligationOrganType"
                  :rules="[
                    { required: requiredRules[type].obligationOrganType || false, message: '请选择赔偿义务机关类型', trigger: 'blur' }
                  ]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-card__type"
                    v-model="person.obligationOrganType"
                    style="width: 100%"
                    :clearable="!requiredRules[type].obligationOrganType"
                    placeholder="请选择赔偿义务机关类型"
                    @change="setLabelBaseValue($event, options.obligationOrganType, person, 'value', { 'obligationOrganTypeName': 'label' }, 'obligationOrganType')"
                  >
                    <el-option
                      v-for="(item, index) in options.obligationOrganType"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.obligationOrganTypeName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              赔偿义务机关--名字-->
              <el-col :span="24" v-if="visible('obligationOrganName')">
                 <el-form-item
                    label="赔偿义务机关："
                    prop="name"
                    :rules="[
                     { required: requiredRules[type].name || false, message: '请输入赔偿义务机关名字', trigger: 'blur' }
                    ]"
                  >
                        <el-input
                          v-if="!person.readonly"
                          v-model.trim="person.name"
                          placeholder="请输入赔偿义务机关名字"
                          maxlength="100"
                          show-word-limit
                        ></el-input>
                        <div v-else class="readonly-text-field">
                          {{ person.name || '-' }}
                        </div>
                      </el-form-item>
              </el-col>
<!--              赔偿义务机关---地址类型-->
              <el-col :span="24" v-if="!person.readonly && visible('obligationOrganAddressType')">
                 <el-form-item
                  label="地址类型："
                  prop="addressType"
                  :rules="[
                    { required: requiredRules[type].addressType || false, message: '请选择地址类型' }
                  ]"
                >
                  <el-radio-group v-model="person.addressType">
                        <el-radio label="0">经常居住地</el-radio>
                        <el-radio label="1">户籍所在地</el-radio>
                      </el-radio-group>
                </el-form-item>
              </el-col>
<!--              赔偿义务机关---住所地-->
              <el-col :span="24" v-if="visible('obligationOrganAddressAreaCode')">
                 <el-form-item
                  label="住所地："
                  prop="addressAreaCode"
                  :rules="[
                    { required: requiredRules[type].addressAreaCode || false, message: '请选择住所地', trigger: 'blur' }
                  ]"
                >
                  <el-cascader
                    v-if="!person.readonly"
                    ref="provienceCityAres"
                    v-model="person.addressAreaCode"
                    style="flex: 1"
                    :options="options.provience"
                    :show-all-levels="true"
                    :props="{
                      expandTrigger: 'hover',
                      value: 'id',
                      label : 'name',
                      children: 'childList',
                      emitPath: false
                    }"
                    clearable
                    @change="provienceCityAresChange($event,'provienceCityAres',person, 'agentAddressInput', 'addressAreaCode')"
                  />
                  <div v-else class="readonly-text-field">{{ person.addressAreaCodeName || '-' }}</div>
                </el-form-item>
              </el-col>
<!--              赔偿义务机关---详细地址-->
              <el-col :span="24" v-if="visible('obligationOrganApplicantDetailedAddress')">
                <el-form-item
                  label="详细地址："
                  prop="applicantDetailedAddress"
                  :rules="[
                    { required: requiredRules[type].applicantDetailedAddress || false, message: '请输入详细地址', trigger: 'blur' },
                    { validator: validateAddressCredit('provienceCityAres', person), trigger: 'blur' }
                  ]"
                >
                <el-input
                    v-if="!person.readonly"
                    ref="agentAddressInput"
                    v-model.trim="person.applicantDetailedAddress"
                    maxlength="100"
                    show-word-limit
                    placeholder="请输入详细地址（街道、楼牌号等）"
                />
                <div v-else class="readonly-text-field">{{ person.applicantDetailedAddress || '-' }}</div>
                </el-form-item>
              </el-col>
<!--              赔偿义务机关---提示-->
              <el-col :span="24" v-if="!person.readonly && visible('obligationOrganAddressTips')">
                <div class="address-tips" style="padding-bottom: 5px">
                 <el-form-item class="warning-rows">
                   <i class="el-icon el-icon-warning" style="font-size: 20px"></i>
                   {{ person.peopleType === '0' ? '经常居住地指的是：公民离开户籍所在地至起诉时连续居住一年以上的地方' : '住所地指的是：主要办事机构所在地/主要营业地/注册登记地' }}
                 </el-form-item>
                 <el-form-item class="warning-rows">
                   <i class="el-icon el-icon-warning" style="font-size: 20px"></i>地址格式范例：北京市东城区长安街1室101号
                 </el-form-item>
                </div>
              </el-col>
<!--              赔偿义务机关---法定代表人姓名-->
              <el-col :span="12" v-if="visible('obligationOrganLeaderName')">
                <el-form-item
                  label="法定代表人姓名："
                  prop="leaderName"
                  :rules="[
                    { required: requiredRules[type].leaderName || false, message: '请输入法定代表人姓名', trigger: 'blur' },
                    { validator: validateRuleName, trigger: 'blur' }
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model="person.leaderName"
                    placeholder="请输入法定代表人姓名"
                    maxlength="16"
                    show-word-limit
                    @input="limitWords('name', person, 'leaderName')"
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.leaderName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              赔偿义务机关---法定代表人职务-->
              <el-col :span="12" v-if="visible('obligationOrganPostName')">
                <el-form-item
                  label="法定代表人职务："
                  prop="postName"
                  :rules="[
                    { required: requiredRules[type].postName || false, message: '请输入法定代表人职务', trigger: 'blur' },
                    { min: 2, max: 9, message: '长度在 2 到 9 个字符', trigger: 'blur' }
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model.trim="person.postName"
                    placeholder="请输入法定代表人职务"
                    maxlength="9"
                    show-word-limit
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.postName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              赔偿义务机关---法定代表人手机号码-->
              <el-col :span="12" v-if="visible('obligationOrganMobilePhone')">
                <el-form-item
                  label="法定代表人手机号码："
                  prop="mobilePhone"
                  :rules="[
                    { required:requiredRules[type].mobilePhone || false, message: '请输入法定代表人手机号码', trigger: 'blur' },
                    { validator: validateMobilePhone, trigger: 'blur' }
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model.trim="person.mobilePhone"
                    placeholder="请输入法定代表人手机号码"
                    maxlength="11"
                    show-word-limit
                    @input="limitWords('digit', person, 'mobilePhone')"
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.mobilePhone || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              法人、负责人姓名-->
              <el-col :span="8" v-if="visible('leaderName')">
                <el-form-item
                  :label="getPeopleTypeName(person) + '姓名：'"
                  prop="leaderName"
                  :rules="[
                    { required: requiredRules[type].leaderName || false, message: getPlaceHolder('输入', getPeopleTypeName(person), '姓名'), trigger: 'blur' },
                    { validator: validateRuleName, trigger: 'blur' }
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model="person.leaderName"
                    :placeholder="getPlaceHolder('输入', getPeopleTypeName(person), '姓名')"
                    maxlength="16"
                    show-word-limit
                    @input="limitWords('name', person, 'leaderName')"
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.leaderName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              法人、负责人职务-->
              <el-col :span="8" v-if="visible('postName')">
                <el-form-item
                  :label="getPeopleTypeName(person) + '职务：'"
                  prop="postName"
                  :rules="[
                    { required: requiredRules[type].postName || false, message: getPlaceHolder('输入', getPeopleTypeName(person), '职务'), trigger: 'blur' },
                    { min: 2, max: 9, message: '长度在 2 到 9 个字符', trigger: 'blur' }
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model.trim="person.postName"
                    :placeholder="getPlaceHolder('输入', getPeopleTypeName(person), '职务')"
                    maxlength="9"
                    show-word-limit
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.postName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              手机号码-->
              <el-col :span="8" v-if="visible('mobilePhone')">
                <el-form-item
                  label="手机号码："
                  prop="mobilePhone"
                  :rules="[
                    { required:requiredRules[type].mobilePhone || false, message: getPlaceHolder('输入', getPeopleTypeName(person), '手机号码'), trigger: 'blur' },
                    { validator: validateMobilePhone, trigger: 'blur' }
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model.trim="person.mobilePhone"
                    :placeholder="getPlaceHolder('输入', getPeopleTypeName(person), '手机号码')"
                    maxlength="11"
                    show-word-limit
                    @input="limitWords('digit', person, 'mobilePhone')"
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.mobilePhone || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              法人、负责人证件类型-->
              <el-col :span="8" v-if="visible('cardType')">
                <el-form-item
                  label="证件类型："
                  prop="cardType"
                  :rules="[
                    { required: requiredRules[type].cardType || false, message: getPlaceHolder('选择', getPeopleTypeName(person), '证件类型'), trigger: 'blur' }
                  ]"
                >
                  <el-select
                    v-if="!person.readonly"
                    id="BatchRecord-card__type"
                    v-model="person.cardType"
                    :clearable="!requiredRules[type].cardType"
                    style="width: 100%"
                    :placeholder="getPlaceHolder('选择', getPeopleTypeName(person), '证件类型')"
                    @change="setLabelBaseValue($event, options.cardType, person, 'value', { 'cardTypeName': 'label' }, 'cardType', 'clearCardNumber')"
                  >
                    <el-option
                      v-for="(item, index) in options.cardType"
                      :key="index"
                      :value="item.value"
                      :label="item.label"
                    />
                  </el-select>
                  <div v-else class="readonly-text-field">
                    {{ person.cardTypeName || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              法人、负责人证件号-->
              <el-col :span="8" v-if="visible('cardNumber')">
                <el-form-item
                  label="证件号码："
                  prop="cardNumber"
                  :rules="[
                    { required: requiredRules[type].cardNumber || false, message: getPlaceHolder('输入', getPeopleTypeName(person), '证件号码'), trigger: 'blur' },
                    { validator: validateCardNumByType(person), trigger: 'blur' },
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model.trim="person.cardNumber"
                    :disabled="!isDef(person.cardType)"
                    :placeholder="getPlaceHolder('输入', getPeopleTypeName(person), '证件号码')"
                    maxlength="50"
                    show-word-limit
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.cardNumber || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              单位固定电话-->
              <el-col :span="8" v-if="visible('phone')">
                <el-form-item
                  label="固定电话："
                  prop="phone"
                  :rules="[{ required: requiredRules[type].phone || false, message: '请输入单位固定电话', trigger: 'blur' }]"
                >
                  <el-input
                    v-if="!person.readonly"
                    v-model="person.phone"
                    placeholder="请输入单位固定电话"
                    maxlength="50"
                    show-word-limit
                  />
                  <div v-else class="readonly-text-field">
                    {{ person.phone || '-' }}
                  </div>
                </el-form-item>
              </el-col>
<!--              住所地-->
              <el-col :span="8" v-if="visible('addressAreaCode')">
                <el-form-item
                  label="住所地："
                  prop="addressAreaCode"
                  :rules="[
                    { required: requiredRules[type].addressAreaCode || false, message: '请选择住所地', trigger: 'blur' }
                  ]"
                >
                  <el-cascader
                    v-if="!person.readonly"
                    ref="provienceCityAres"
                    v-model="person.addressAreaCode"
                    style="flex: 1"
                    :options="options.provience"
                    :show-all-levels="true"
                    :props="{
                      expandTrigger: 'hover',
                      value: 'id',
                      label : 'name',
                      children: 'childList',
                      emitPath: false
                    }"
                    clearable
                    @change="provienceCityAresChange($event,'provienceCityAres',person, 'agentAddressInput', 'addressAreaCode')"
                  />
                  <div v-else class="readonly-text-field">{{ person.addressAreaCodeName || '-' }}</div>
                </el-form-item>
              </el-col>
<!--              详细地址-->
              <el-col :span="16" v-if="visible('applicantDetailedAddress')">
                <el-form-item
                  label="详细地址："
                  prop="applicantDetailedAddress"
                  :rules="[
                    { required: requiredRules[type].applicantDetailedAddress || false, message: '请输入详细地址', trigger: 'blur' },
                    { validator: validateAddressCredit('provienceCityAres', person), trigger: 'blur' }
                  ]"
                >
                  <el-input
                    v-if="!person.readonly"
                    ref="agentAddressInput"
                    v-model.trim="person.applicantDetailedAddress"
                    maxlength="100"
                    show-word-limit
                    placeholder="请输入详细地址（街道、楼牌号等）"
                  />
                  <div v-else class="readonly-text-field">{{ person.applicantDetailedAddress || '-' }}</div>
                </el-form-item>
              </el-col>
           </el-row>
          <div class="address-tips" v-if="!person.readonly && visible('addressTips')">
                <el-form-item class="warning-rows">
<!--                  <img class="tips" src="./suitStatic/image/icon-tip&#45;&#45;orange.png" alt="提示图标">-->
                  <i class="el-icon-warning tips" style="font-size: 20px"></i>
                  {{ person.peopleType === '0' ? '经常居住地指的是：公民离开户籍所在地至起诉时连续居住一年以上的地方' : '住所地指的是：主要办事机构所在地/主要营业地/注册登记地' }}
                </el-form-item>
                <el-form-item class="warning-rows">
                  <i class="el-icon-warning tips" style="font-size: 20px"></i>地址格式范例：北京市东城区长安街1室101号
                </el-form-item>
          </div>
          <div v-if="!person.readonly" class="casePeron-submit">
            <el-button type="primary" @click="saveCasePerson(person.pid, person, index)">保存</el-button>
            <el-button type="default" @click="cancelSaveCasePerson(person, index)">取消</el-button>
          </div>
        </el-form>
       </div>
      </div>
    </div>
  `,
  mounted() {
    this.$nextTick(() => {
      console.log(this)
    })
  },
  watch: {
    value: {
      deep: true,
      handler(val) {
        this.$nextTick(() => {
          this.setId(val)
        })
      }
    }
  },
  data() {
    return {
      //  各个类型的当事人名字
      typeName: {
        0: '原告当事人', // 起诉、行政、执行
        1: '被告当事人', // 起诉、行政、执行
        2: '第三人', // 起诉、新政、执行
        3: '原告代理人', // 起诉、行政、执行
        4: '证人', // 起诉、宣告死亡、执行、行政、行为能力认定、监护人指定异议、维护关系变更、实现物品担保权、调解协议司法确认
        5: '申请人', // 宣告死亡、执行、保全、调解、调解协议司法确认
        6: '被申请人', // 宣告死亡、执行、保全、调解、实现物品担保权
        7: '申请人代理人', // 宣告死亡、执行、保全、行为能力认定、调解协议司法确认、实现物品担保权
        8: '申请人', // 行为能力认定（new：申请人类型 ）
        9: '被申请人', // 行为能力认定（new：申请事项）
        10: '异议人', // 监护人指定异议
        11: '异议人代理人', // 监护人指定异议
        12: '起诉人', // 维护关系变更（new：起诉人类型）
        13: '被诉监护人', // 维护关系变更
        14: '起诉人代理人', // 维护关系变更
        15: '申请人', // 实现物品担保权（new：申请人类型）
        16: '赔偿请求人', //  自赔（new: 申请人类型 ）
        17: '赔偿义务机关', //  自赔
        18: '代理人' //  自赔
      },
      //  各个类型的当事人表单必填字段
      requiredRules: {
        0: {
          peopleType: true,
          name: true,
          sex: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          nation: true,
          bornDate: true,
          age: true,
          occupation: false,
          unitName: false,
          phone: false,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true,
          unitNature: false,
          licenseType: true,
          licenseNumber: true,
          leaderName: true,
          postName: true
        },
        1: {
          peopleType: true,
          name: true,
          sex: true,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true
        },
        2: {
          peopleType: true,
          name: true,
          sex: true,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true
        },
        3: {
          name: true,
          agentType: true,
          belongToPlantiff: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          licenseNumber: true,
          registeredAddress: true
        },
        4: {
          name: true,
          mobilePhone: true,
          sex: true,
          addressAreaCode: true,
          applicantDetailedAddress: true
        },
        5: {
          peopleType: true,
          name: true,
          sex: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          nation: true,
          bornDate: true,
          age: true,
          occupation: false,
          unitName: false,
          phone: false,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true,
          unitNature: false,
          licenseType: true,
          licenseNumber: true,
          leaderName: true,
          postName: true
        },
        6: {
          peopleType: true,
          name: true,
          sex: true,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true
        },
        7: {
          name: true,
          agentType: true,
          belongToPlantiff: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          licenseNumber: true,
          registeredAddress: true
        },
        8: {
          applyPersonType: true,
          peopleType: true,
          name: true,
          sex: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          nation: true,
          bornDate: true,
          age: true,
          occupation: false,
          unitName: false,
          phone: false,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true,
          unitNature: false,
          licenseType: true,
          licenseNumber: true,
          leaderName: true,
          postName: true
        },
        9: {
          applyMatter: true,
          peopleType: true,
          name: true,
          sex: true,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true
        },
        10: {
          peopleType: true,
          name: true,
          sex: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          nation: true,
          bornDate: true,
          age: true,
          occupation: false,
          unitName: false,
          phone: false,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true,
          unitNature: false,
          licenseType: true,
          licenseNumber: true,
          leaderName: true,
          postName: true
        },
        11: {
          name: true,
          agentType: true,
          belongToPlantiff: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          licenseNumber: true,
          registeredAddress: true
        },
        12: {
          prosecutionType: true,
          peopleType: true,
          name: true,
          sex: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          nation: true,
          bornDate: true,
          age: true,
          occupation: false,
          unitName: false,
          phone: false,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true,
          unitNature: false,
          licenseType: true,
          licenseNumber: true,
          leaderName: true,
          postName: true
        },
        13: {
          peopleType: true,
          name: true,
          sex: true,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true
        },
        14: {
          name: true,
          agentType: true,
          belongToPlantiff: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          licenseNumber: true,
          registeredAddress: true
        },
        15: {
          applyPersonType: true,
          peopleType: true,
          name: true,
          sex: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          nation: true,
          bornDate: true,
          age: true,
          occupation: false,
          unitName: false,
          phone: false,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true,
          unitNature: false,
          licenseType: true,
          licenseNumber: true,
          leaderName: true,
          postName: true
        },
        16: {
          applyPersonType: true,
          peopleType: true,
          name: true,
          sex: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          nation: true,
          bornDate: true,
          age: true,
          occupation: false,
          unitName: false,
          phone: false,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true,
          unitNature: false,
          licenseType: true,
          licenseNumber: true,
          leaderName: true,
          postName: true
        },
        17: {
          obligationOrganType: true,
          name: true,
          addressType: true,
          addressAreaCode: true,
          applicantDetailedAddress: true,
          leaderName: false,
          mobilePhone: false,
          postName: false
        },
        18: {
          name: true,
          agentType: true,
          belongToPlantiff: true,
          mobilePhone: true,
          cardType: true,
          cardNumber: true,
          licenseNumber: true,
          registeredAddress: true
        }
      },
      // 各个类型的当事人表单显示字段
      typeKeys: {
        // 原告
        0: ['peopleType', 'blankPlaceholder', 'import', 'name', 'sex', 'mobilePhone', 'cardType', 'cardNumber', 'nation',
          'bornDate', 'age', 'setUsuallyPerson', 'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress', 'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName', 'addressTips'
        ],
        // 被告
        1: ['peopleType', 'blankPlaceholder', 'import', 'name', 'sex', 'mobilePhone', 'cardType', 'cardNumber', 'nation',
          'bornDate', 'age', 'setUsuallyPerson',
          'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress',
          'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName',
          'addressTips'
        ],
        // 第三人
        2: ['peopleType', 'blankPlaceholder', 'import', 'name', 'sex', 'mobilePhone', 'cardType', 'cardNumber', 'nation',
          'bornDate', 'age', 'setUsuallyPerson',
          'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress',
          'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName',
          'addressTips'
        ],
        // 代理人
        3: ['agentType', 'belongToPlantiffAgent', 'import', 'name', 'mobilePhone', 'cardType', 'cardNumber',
          'licenseNumber', 'registeredAddress', 'setUsuallyPerson'
        ],
        //  证人
        4: ['belongToPlantiffWitness', 'inCourt', 'name', 'mobilePhone', 'sex', 'cardType',
          'cardNumber',
          'bornDate', 'age', 'unitName', 'addressAreaCode', 'applicantDetailedAddress'

        ],
        // 申请人-----宣告死亡、执行、保全、调解、调解协议司法确认
        5: ['peopleType', 'blankPlaceholder', 'import', 'name', 'sex', 'mobilePhone', 'cardType', 'cardNumber', 'nation',
          'bornDate', 'age', 'setUsuallyPerson',
          'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress',
          'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName',
          'addressTips'
        ],
        // 被申请人----宣告死亡、执行、保全、调解、调解协议司法确认
        6: ['peopleType', 'blankPlaceholder', 'import', 'name', 'sex', 'mobilePhone', 'cardType', 'cardNumber', 'nation',
          'bornDate', 'age', 'setUsuallyPerson',
          'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress',
          'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName',
          'addressTips'
        ],
        // 申请人代理人-----宣告死亡、执行、保全、行为能力认定、调解协议司法确认、实现物品担保权
        7: ['agentType', 'belongToPlantiffAgent', 'import', 'name', 'mobilePhone', 'cardType', 'cardNumber',
          'licenseNumber', 'registeredAddress', 'setUsuallyPerson'
        ],
        // 行为能力认定---申请人
        8: ['applyPersonTypePowerIdentify', 'peopleType', 'import', 'name', 'sex', 'mobilePhone',
          'cardType', 'cardNumber', 'nation', 'bornDate', 'age', 'setUsuallyPerson',
          'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress',
          'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName',
          'addressTips'
        ],
        // 被申请人---行为能力认定
        9: ['applyMatterPowerIdentify', 'peopleType', 'import', 'name', 'sex', 'mobilePhone', 'cardType',
          'cardNumber', 'nation', 'bornDate', 'age', 'setUsuallyPerson',
          'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress',
          'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName',
          'addressTips'
        ],
        // 异议人----监护人指定异议
        10: ['peopleType', 'blankPlaceholder', 'import', 'name', 'sex', 'mobilePhone', 'cardType', 'cardNumber', 'nation',
          'bornDate', 'age', 'setUsuallyPerson',
          'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress',
          'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName',
          'addressTips'
        ],
        // 异议人代理人----监护人指定异议
        11: ['agentType', 'belongToPlantiffAgent', 'import', 'name', 'mobilePhone', 'cardType',
          'cardNumber', 'setUsuallyPerson', 'licenseNumber', 'registeredAddress'
        ],
        // 起诉人----维护关系变更
        12: ['prosecutionType', 'peopleType', 'import', 'name', 'sex', 'mobilePhone', 'cardType',
          'cardNumber', 'nation', 'bornDate', 'age', 'setUsuallyPerson',
          'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress',
          'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName',
          'addressTips'
        ],
        // 被诉监护人----维护关系变更
        13: ['peopleType', 'blankPlaceholder', 'import', 'name', 'sex', 'mobilePhone', 'cardType', 'cardNumber', 'nation',
          'bornDate', 'age', 'setUsuallyPerson',
          'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress',
          'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName',
          'addressTips'
        ],
        // 起诉人代理人----维护关系变更
        14: ['agentType', 'belongToPlantiffAgent', 'import', 'name', 'mobilePhone', 'cardType',
          'cardNumber', 'setUsuallyPerson',
          'licenseNumber', 'registeredAddress'
        ],
        // 申请人----实现物品担保权
        15: ['applyPersonTypeItem', 'peopleType', 'import', 'name', 'sex', 'mobilePhone', 'cardType',
          'cardNumber', 'nation', 'bornDate', 'age', 'setUsuallyPerson',
          'occupation', 'unitName', 'phone', 'addressType', 'addressAreaCode',
          'applicantDetailedAddress',
          'business_info', 'unitNature', 'licenseType', 'licenseNumber', 'leaderName', 'postName',
          'addressTips'
        ],
        // 申请人---- 自赔
        16: ['applyPersonTypeFromCourt', 'peopleType', 'import', 'name', 'sex', 'mobilePhone', 'setUsuallyPerson',
          'cardType', 'cardNumber', 'nation', 'bornDate', 'age', 'occupation', 'unitName', 'phone',
          'addressType', 'addressAreaCode', 'applicantDetailedAddress', 'business_info', 'unitNature',
          'licenseType', 'licenseNumber', 'leaderName', 'postName', 'addressTips'
        ],
        17: ['obligationOrganType', 'obligationOrganName', 'obligationOrganAddressTips', 'obligationOrganAddressAreaCode',
          'obligationOrganAddressType', 'obligationOrganApplicantDetailedAddress', 'obligationOrganLeaderName',
          'obligationOrganPostName', 'obligationOrganMobilePhone'
        ],
        // 代理人---- 自赔
        18: ['agentType', 'belongToPlantiffAgent', 'import', 'name', 'mobilePhone', 'cardType',
          'cardNumber', 'licenseNumber', 'registeredAddress', 'setUsuallyPerson'
        ]
      },
      peopleTypeMap: {
        0: '自然人',
        1: '法人',
        2: '非法人组织'
      },
      plusIcon: './suitStatic/image/icon-add--white.png',
      // 编辑时，保存的表单字段
      savePersonsForm: {}
    }
  },
  inject: ['plaintiffPersons', 'allCasePerson'],
  computed: {
    headerTitle() {
      return index => {
        return this.type !== '17' ? this.typeName[this.type] + numberTransferChinese(index + 1) : this.typeName[this.type]
      }
    },
    visible() {
      const {
        typeKeys,
        type
      } = this
      return function(key) {
        return typeKeys[type].includes(key)
      }
    },
    allPerson() {
      return this.allCasePerson()
    },
    getPlaintiffPersons() {
      return this.plaintiffPersons()
    },
    isOverSelect() {
      return (item, {
        belongToPlantiff
      }) => {
        if (!$validate.isArray(belongToPlantiff)) return true
        return belongToPlantiff.includes(item.pid) ? false : belongToPlantiff.length >= 2
      }
    },
    isOverSelected() {
      return item => {
        const {
          value
        } = this
        const {
          pid
        } = item
        return value.filter(person => person.readonly &&
          $validate.isArray(person.belongToPlantiff) &&
          person.belongToPlantiff.includes(pid)
        ).length < 2
      }
    },
    importBtnName() {
      return person => {
        return person.type === '3' ? '代理人' : {
          0: '自然人',
          1: '法人',
          2: '组织'
        } [person.peopleType]
      }
    }
  },
  methods: {
    setId(val) {
      if(!val || !val.length) return
      val.forEach(({ pid }, index) => {
        const wrapper = document.querySelector(`div[name=Person_${pid}]`)
        const inputs = wrapper.querySelectorAll('.el-form-item')
        inputs.forEach(ele => {
          const label = ele.querySelector('label.el-form-item__label')
          const input = ele.querySelector('input')
          if(input) {
            input.setAttribute('id', this.type + '_' + label.getAttribute('for') + '_' + index)
          }
        })
      })
    },
    // 公共提示
    sendWarningMessage(type, message, duration = 1500) {
      sendMessage({
        cmd: 'messageTips',
        type,
        message,
        duration
      })
    },
    isDef(val) {
      return val !== '' && val !== undefined && val !== null
    },
    // 取消
    cancelSaveCasePerson(person) {
      const time = new Date().getTime()
      sendMessage({
        cmd: 'parentConfirmBox',
        config: {
          confirmButtonText: '确认',
          cancelButtonText: '取消',
          message: `您确定要取消${person.isAdd ? '新增' : '修改'}${this.typeName[this.type]}？`,
          title: '提示',
          type: 'warning'
        },
        current: time
      })
      eventHandler.$on('confirmBoxHandler', res => {
        const {
          action,
          current
        } = res.params
        if (current !== time) return
        if (action === 'confirm') {
          if (person.isAdd) {
            this.$emit('input', this.value.filter(item => item.pid !== person.pid))
          } else {
            this.$emit('input', this.value.map(item => {
              if (person.pid === item.pid) {
                return JSON.parse(this.savePersonsForm[person.pid])
              } else {
                return item
              }
            }))
          }
        }
        eventHandler.$off('confirmBoxHandler')
      })
    },
    // 保存
    saveCasePerson(ref, person, index) {
      this.$refs[ref][0].validate().then(() => {
        this.$set(person, 'readonly', true)
        this.$emit('change', {
          type: person.isAdd ? 'add' : 'update',
          person
        })
        delete person.isAdd
      })
    },
    // 地区发生变化时，赋予当事人住所地address值
    provienceCityAresChange(event, refs, person, input, prop, address = 'applicantDetailedAddress') {
      const context = $validate.isArray(this.$refs[refs]) ? this.$refs[refs][0].getCheckedNodes()
        : this.$refs[refs].getCheckedNodes()
      if (context.length > 0) {
        person[address] = context[0].pathLabels.join('')
        person.addressAreaCodeName = person[address]
        const contextInput = this.$refs[input]
        if (contextInput instanceof Array) {
          contextInput[0] && contextInput[0].focus()
        } else {
          contextInput && contextInput.focus()
        }
      } else {
        person.addressAreaCodeName = ''
      }
      prop && this.$refs[person.pid][0] && this.$refs[person.pid][0].validateField(prop)
    },
    // 根据日期设置年龄
    setAgeByDate(person) {
      if (!person.bornDate) {
        person.age = ''
        return
      }
      const timeStep = new Date().getTime()
      sendMessage({
        cmd: 'iframeGetData',
        params: {
          api: ['getServerDate'],
          timeStep
        }
      })
      eventHandler.$on('getServerDate', (res) => {
        const {
          from
        } = res
        if (from.timeStep !== timeStep) return
        if (!res.data || !res.data.data) return
        const currentDate = new Date(res.data.data.replace(/-/g, '/'))
        person.age = getAgeByDateTime(person.bornDate, currentDate)[0]
        eventHandler.$off('getServerDate')
      })
    },
    clearLawInfo(val, person) {
      if (val !== '0' && val !== '1') {
        person.licenseNumber = ''
        person.registeredAddress = ''
      }
    },
    clearLicenseNumber(val, person) {
      const formRef = person.pid
      if (!val) {
        person.licenseNumber = ''
        this.$nextTick(() => {
          if (this.$refs[formRef] instanceof Array) {
            this.$refs[formRef].length > 0 && this.$refs[formRef][0].validateField(
              'licenseNumber')
          } else {
            this.$refs[formRef] && this.$refs[formRef].validateField('licenseNumber')
          }
        })
      }
    },
    clearCardNumber(val, person) {
      const formRef = person.pid
      if (!val) {
        person.cardNumber = ''
        this.$nextTick(() => {
          if (this.$refs[formRef] instanceof Array) {
            this.$refs[formRef].length > 0 && this.$refs[formRef][0].validateField('cardNumber')
          } else {
            this.$refs[formRef] && this.$refs[formRef].validateField('cardNumber')
          }
        })
      }
    },
    setLabelBaseValue(val, option, person, value, map = {}, prop, extraFunc) {
      const keys = Object.keys(map)
      if (!val || !val.length) {
        keys.forEach(key => {
          person[key] = ''
        })
      } else {
        if ($validate.isArray(val)) {
          const U = option.filter(item => val.includes(item[value]))
          keys.forEach(key => {
            person[key] = U.map(item => {
              return item[map[key]]
            }).join(',')
          })
        } else {
          const T = option.find(item => item[value] === val)
          keys.forEach(key => {
            person[key] = T[map[key]]
          })
        }
      }
      prop && this.$refs[person.pid][0] && this.$refs[person.pid][0].validateField(prop)
      extraFunc && typeof this[extraFunc] === 'function' && this[extraFunc](val, person)
    },
    getPeopleTypeName(person) {
      return  {
        0: '自然人',
        1: '法人',
        2: '主要负责人'
      } [person.peopleType]
    },
    getPlaceHolder(wei, bin, key) {
      const {
        typeName,
        type
      } = this
      return `请${wei}${bin || typeName[type]}${key}`
    },
    limitWords(type, origin = this, key) {
      let reg
      switch (type) {
        case 'digit':
          reg = /[^\d]/g
          break;
        case 'float':
          reg = /[^\d{1,}\.\d{1,}|\d{1,}]/g
          break;
        case 'name':
          //  只能输入中英文
          reg = /[^\a-zA-Z\u4E00-\u9FA5\㛑]/g
          break
        default:
          break
      }
      if (reg) origin[key] = origin[key].replace(reg, '')
    },
    // 当事人编辑
    casePersonEdit(person, index) {
      if (this.allPerson.filter(item => !item.readonly).length) {
        this.sendWarningMessage('warning', '您有正在编辑的当事人信息，请先完成编辑')
        return
      }
      this.savePersonsForm[person.pid] = JSON.stringify(person)
      person.readonly = false
    },
    //  当事人删除
    casePersonDelete(person, index) {
      const time = new Date().getTime()
      const {
        typeName,
        type
      } = this
      sendMessage({
        cmd: 'parentConfirmBox',
        config: {
          confirmButtonText: '确认',
          cancelButtonText: '取消',
          message: `您确定要删除${typeName[type]}：${person.name}？`,
          title: '提示',
          type: 'warning'
        },
        current: time
      })
      eventHandler.$on('confirmBoxHandler', res => {
        const {
          action,
          current
        } = res.params
        if (current !== time) return
        if (action === 'confirm') {
          this.$emit('input', this.value.filter(item => item.pid !== person.pid))
          this.$emit('change', {
            type: 'delete',
            person
          })
        }
        eventHandler.$off('confirmBoxHandler')
      })
    },
    openParentConfirmBox(current, config) {
      sendMessage({
        cmd: 'parentConfirmBox',
        config,
        current
      })
    },
    // 设为常用人
    setCommonUseCasePerson(person) {
      const time = new Date().getTime()
      this.openParentConfirmBox(time, {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        message: `注意：在当事人类型相同与人员类型相同的情况下，
          设为常用人会覆盖掉保已经设置过的相同证件号的自然人、法人、非法人组织、代理人信息`,
        title: '提示',
        type: 'warning'
      })
      eventHandler.$on('confirmBoxHandler', res => {
        eventHandler.$off('confirmBoxHandler')
        const {
          action,
          current
        } = res.params
        if (current !== time) return
        if (action === 'confirm') {
          const timeStep = new Date().getTime()
          sendMessage({
            cmd: 'iframeGetData',
            params: {
              api: [{
                "setCommonUseCasePerson": person
              }],
              timeStep
            }
          })
          eventHandler.$on('setCommonUseCasePerson', res => {
            eventHandler.$off('setCommonUseCasePerson')
            const {
              from,
              error
            } = res
            if (from.timeStep !== timeStep) return
            this.sendWarningMessage(error ? 'error' : 'success', error ? '网络异常，请稍后重试' : '设为常用人成功！')
          })
        }
      })
    },
    //  导入
    handleImport(person) {
      this.$emit('import', person)
    },
    clearFormAndValidate(person) {
      const keys = ["name", "postName", "cardType", "cardTypeName", "cardNumber", "nation",
        "nationName", "sex", "sexName", "occupation", "occupationName", "age",
        "mobilePhone", "applicantDetailedAddress", "bornDate",
        "postalCode", "unitName", "unitNature", "unitNatureName", "addressAreaCodeName",
        "licenseType", "licenseTypeName", "licenseNumber", "phone", "leaderName", 'addressAreaCode'
      ]
      keys.forEach(key => {
        person[key] = ''
      })
      this.$nextTick(() => {
        this.$refs[person.pid][0].clearValidate()
      })
    },
    validateRuleName(rule, value, callback) {
      if (!value) callback()
      else {
        // eslint-disable-next-line no-undef
        $validate.isRuleName(value) ? callback() : callback(new Error('请输入2到16位中英文'))
      }
    },
    validateMobilePhone(rule, value, callback) {
      if (!value) callback()
      else {
        $validate.isMobilePhoneNum(value) ? callback() : callback(new Error('手机号码格式错误'))
      }
    },
    // 根据类型验证证件号
    // 柯里化函数
    validateCardNumByType(person) {
      const type = person.cardType
      // 查出所有当事人中证件类型相同的排除自己的所有当事人
      const persons = this.allPerson.filter(item => item.cardType === type && person.pid !== item.pid)
      // 验重函数
      const cardNumberDuplicate = (value, callback) => {
        // 如果存在有
        return persons.filter(item => item.cardNumber === value).length ? callback(new Error(
          '证件号存在重复，请核对后再保存')) : callback()
      }
      return (rule, value, callback) => {
        if (!value || !type) {
          callback()
        }
        if (!validateMapCardType[type]) {
          callback()
        } else {
          // 多个验证条件的情况下 满足一条即可
          if (validateMapCardType[type] instanceof Array) {
            if (validateMapCardType[type].some(item => {
              return typeof item === 'function' ? item(value) : item.test(value)
            })) {
              // 验证通过后 证件号查重
              return cardNumberDuplicate(value, callback)
            } else {
              callback(new Error('该证件类型下，证件号格式错误'))
            }
          } else {
            // 否则只要满足正则即可
            const res = typeof validateMapCardType[type] === 'function' ? validateMapCardType[type](value) : validateMapCardType[type].test(value)
            if (res) {
              return cardNumberDuplicate(value, callback)
            } else {
              callback(new Error('该证件类型下，证件号格式错误'))
            }
          }
        }
      }
    },
    validateLicenseNumberByType(person) {
      const type = person.licenseType
      const licenseNumberDuplicate = (value, callback) => {
        // 获取原告、被告、当事人中  排除自身后， 不为自然人并且证照类型相同的组织、非组织机构
        const persons = this.allPerson
          .filter(u => ['1', '2'].includes(u.peopleType) && person.pid !== u.pid && person
            .licenseType === u.licenseType)
        return persons.filter(u => value === u.licenseNumber).length ? callback(new Error(
          '证照号存在重复，请核对后再保存')) : callback()
      }
      return function(rule, value, callback) {
        if (!value || !type) {
          callback()
        }
        if (!validateMapLicenseType[type]) {
          callback()
        } else {
          if (validateMapLicenseType[type] instanceof Array) {
            if (validateMapLicenseType[type].some(item => item.test(value))) {
              return licenseNumberDuplicate(value, callback)
            } else {
              callback(new Error('该证件类型下，证照号码格式错误'))
            }
          } else {
            if (validateMapLicenseType[type].test(value)) {
              return licenseNumberDuplicate(value, callback)
            } else {
              callback(new Error('该证件类型下，证照号码格式错误'))
            }
          }
        }
      }
    },
    validateAddressCredit(addressRef, {
      addressAreaCode
    }) {
      return (rule, value, callback) => {
        if (!value || !addressAreaCode) {
          callback()
        } else {
          const context = $validate.isArray(this.$refs[addressRef]) ? this.$refs[addressRef][0]
            .getCheckedNodes() : this.$refs[addressRef].getCheckedNodes()
          if (context.length > 0) {
            const text = context[0].pathLabels.join('')
            if (value.length <= text.length) {
              callback(new Error('请继续完善详细地址信息'))
            } else {
              callback()
            }
          } else {
            callback()
          }
        }
      }
    },
  },
  install(Vue) {
    Vue.component(this.name, this)
  }
}
