const SfChoice = {
  name: 'SfChoice',
  template: `
   <div class="sf-choice--wrapper">
     <div
       :choiceid="'choice' + id + ' ' + index"
       @click.stop="setChoice(option)"
       :class="{ 'sf-choice--item': true, 'sf-choice--item_active': isChoiced(option), 'sf-choice--item__disabled': option.disabled === true }"
       v-for="(option, index) in options" :key="option[config.value]"
     >
       {{ option[config.label] }}
     <img v-if="isChoiced(option)" class="sf-choice--checked__icon" src="./suitStatic/image/SfChoiced.png" />
     </div>
  </div>`,
  props: {
    // value
    value: {
      required: true,
      type: [String, Array]
    },
    beforeChoice: Function,
    // config.multiple 是否开启多选
    // config.value value字段名
    // config.label 标题字段名
    // config.ifCancel 再次点击时，是否取消勾选
    config: {
      type: Object,
      default: function() {
        return {
          multiple: false,
          value: 'value',
          label: 'label',
          ifCancel: false
        }
      }
    },
    options: {
      type: Array,
      default: function() {
        return []
      }
    }
  },
  data() {
    return {
      id: new Date().getTime()
    }
  },
  watch: {
    options: {
      immediate: true,
      handler(val) {
        setTimeout(() => {
          this.setSplitRow()
        }, 200)
      }
    }
  }
  ,
  created() {
    if(this.config.multiple && !( this.value instanceof Array)) {
      this.$emit('input', [])
    }
  },
  // mounted() {
  //   this.setSplitRow()
  // },
  computed: {
    isChoiced() {
      const { config, value } = this
      const realValue = config.value
      return function(item) {
        if(config.multiple) {
          return value.includes(item[realValue])
        } else {
          return value === item[realValue]
        }
      }
    }
  },
  methods: {
    setSplitRow() {
      // 选择本次渲染组件的全部choice选项
      const choices = document.querySelectorAll(`div[choiceid~=choice${this.id}]`)
      choices.forEach(ele => {
          const nextEl = ele.nextSibling
        if(nextEl) {
          if(ele.getBoundingClientRect().y !== nextEl.getBoundingClientRect().y) {
            nextEl.style.marginTop = '13px'
          }
        }
      })
    },
    doChoice(done) {

    },
    isFunc(val) {
      return Object.prototype.toString.call(val) === '[object Function]'
    },
    setChoice(option) {
      if(option.disabled === true) return
      const { ifCancel, label, multiple, value  } = this.config
      const { beforeChoice, isFunc } = this
      // 不可再次点击取消
     if(!ifCancel) {
       if(multiple) {
         // 多选
         // 已经包含的 不在进行以后操作
         if(this.value.includes(option[value])) return
         // 更新v-model的值为 当前v-mocel值+ 当前点击值
         if(isFunc(beforeChoice)) {
           beforeChoice(() => {
             this.$emit('input', this.value.concat([option[value]]))
             this.$emit('change', option)
           })
         } else {
           this.$emit('input', this.value.concat([option[value]]))
           this.$emit('change', option)
         }
       } else {
         // 单选
         // 已经相等了 不再进行操作
         if(this.value === option[value]) return
         // 更新v-model值为当前点击时的值
         if(isFunc(beforeChoice)) {
           beforeChoice(() => {
             this.$emit('input', option[value])
             this.$emit('change', option)
           })
         } else {
           this.$emit('input', option[value])
           this.$emit('change', option)
         }
       }
     } else {
       // 可以取消
       if(multiple) {
         if(this.value.includes(option[value])) {
           // 包含时， 去除已经选择则的这一项
           this.$emit('input', this.value.filter(val => { return val !== option[value]  }))
         } else {
           this.$emit('input', this.value.concat([option[value]]))
         }
         // 多选
       } else {
         // 单选
         // 相等时 赋值v-model为空
         if(this.value === option[value]) {
           this.$emit('input', '')
         } else {
           this.$emit('input', option[value])
         }
       }
       this.$emit('change', option)
     }
    }
  }
}
