const SfDialog = {
  name: 'SfDialog',
  template: `
    <el-dialog
      :id="id"
      :visible="value"
      :close-on-click-modal="false"
      :close-on-press-escape="false"
      :top="top"
      :width="width"
      :destroy-on-close="destroyOnClose"
      :show-close="false"
      :append-to-body="true"
      @open="dialogOpenEvent"
      @opened="dialogOpenedEvent"
      @close="dialogCloseEvent"
      @closed="dialogClosedEvent"
    >
    <template slot="title">
      <slot name="title">
        <span class="el-dialog__title">{{ title }}</span>
        <button @click.stop="closeDialog" type="button" aria-label="Close" class="el-dialog__headerbtn">
          <img src="./suitStatic/image/icon-close--dialog.png" alt="关闭弹框">
        </button>
      </slot>
    </template>
    <div class="sf-dialog__body" :style="{ maxHeight: screenHeight + 'px' }" slot="default">
       <slot></slot>
    </div>
    <template slot="footer">
      <slot name="footer"></slot>
    </template>
    </el-dialog>
  `,
  props: {
    value: {
      type: Boolean
    },
    title: String,
    width: {
      type: String,
      default: '60%'
    },
    beforeClose: {
      type: [Function, undefined, null]
    },
    customClass: {
      type: String
    },
    destroyOnClose: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      top: '',
      id: '',
      screenHeight: 100
    }
  },
  watch: {
    value: {
      immediate: true,
      handler(val) {
        if(val) {
          sendMessage({
            cmd: 'getScrollTop',
            current: this.id
          })
        }
        sendMessage({
          cmd: 'iframeDialogVisibleChange',
          locked: val
        })
      }
    }
  },
  created() {
    this.id = new Date().getTime()
    eventHandler.$on('scrollTopCallBack', data => {
      const { scrollTop, current, screenHeight, scrollHeight, clientWidth } = data.params
      if(this.id !== current) return
      const isArriveBottom = scrollTop + screenHeight + 40 >= scrollHeight
      this.top = this.screenWidthTransferTop(clientWidth, isArriveBottom) + scrollTop + 'px'
      this.screenHeight = screenHeight * 0.62
    })
  },
  methods: {
    screenWidthTransferTop(w, isArriveBottom) {
     if(w >= 1900)  {
       return isArriveBottom ? 0 : 30
     } else if(w < 1900 && w >= 1440) {
       return isArriveBottom ? -90 : -30
     } else {
       return isArriveBottom ? - 120 : -75
     }
    },
    dialogOpenEvent() {
      parentOverLayShow()
      this.$emit('open')
    },
    dialogOpenedEvent() {
      this.$emit('opened')
    },
    dialogCloseEvent() {
      parentOverLayClose()
      this.$emit('close')
    },
    dialogClosedEvent() {
      this.$emit('closed')
    },
    closeDialog() {
      this.$emit('input', false)
    }
  }
}
