const SfUpload = {
  name: 'SfUpload',
  template: `
       <el-upload
      ref="upload"
      action
      :file-list="value"
      :list-type="listType"
      :multiple="false"
      :on-remove="fileRemove"
      :on-preview="filePreview"
      :disabled="disabled"
      :before-upload="onBeforeUpload"
      :http-request="uploadStart"
      :accept="accept.join(',')"
    >
     <template v-if="listType === 'picture-card'">
          <i v-show="!uploadLoading" class="el-icon el-icon-plus" />
          <i v-show="uploadLoading" class="el-icon el-icon-loading"></i>
      </template>
      <div v-else class="upload-trigger" style="display: flex;flex-flow: row nowrap;align-item: center">
        <el-button
          id="uploadFile"
          size="small"
          slot="trigger"
          style="margin: 0"
          :disabled="disabled"
          :type="buttonType"
          class="el-upload__tip"
        >
          <div class="upload-btn__icons">
            <img src="./suitStatic/image/icon-upload.png" style="width: 15px;height: 17px;margin-right: 8px">
              {{ buttonText }}
            </div>
        </el-button>
        <i v-if="uploadLoading" class="el-icon el-icon-loading" style="font-size: 18px;color: var(--blue);line-height: 32px;margin-left: 13px"></i>
     </div>
     <template slot="tip" v-if="showTip">
       <slot name="tip" >
         <div class="el-upload__tips">文件格式: {{ accept.join('，') }}</div>
       </slot>
     </template>
    </el-upload>
  `,
  props: {
    value: {
      type: Array,
      default: () => []
    },
    // 上传按钮文字
    buttonText: {
      type: String,
      default: '上传'
    },
    current: {
      type: [Number, String],
      default () {
        return ''
      }
    },
    // 接受的文件类型
    accept: {
      type: Array,
      default () {
        return ['.doc', '.docx']
      }
    },
    // 是否可点击
    disabled: {
      type: Boolean,
      default () {
        return false
      }
    },
    // 是否显示上传提示
    showTip: {
      type: Boolean,
      default () {
        return true
      }
    },
    // 按钮类型
    buttonType: {
      type: String,
      default: 'primary'
    },
    // 文件大小限制
    limitSize: {
      type: [Number, Object],
      default () {
        return 1024
      }
    },
    // 上传的文件名参数
    name: {
      type: String,
      default: 'files'
    },
    // 自定义校验
    proxyCheck: {
      type: Function
    },
    dir: {
      type: String,
      default: 'unkown'
    },
    // 自定义参数
    extraParams: {
      type: Object,
      default () {
        return {}
      }
    },
    // 展示形式
    listType: {
      type: String,
      default: 'text'
    },
    // 是否返回多个结果
    // 若是则 加入到文件列表 直至个数限制
    // 若不是则覆盖旧的文件
    mulipte: {
      type: Boolean,
      default () {
        return true
      }
    },
    // 上传的最大个数限制
    // mulipte为true时生效
    limit: {
      type: [String, Number],
      default () {
        return 5
      }
    },
    mapping: {
      type: Object,
      default () {
        return {}
      }
    },
    limitErrorMes: {
      type: String,
      default: ''
    }
  },
  data () {
    return {
      auto: false,
      uploadLoading: false,
      fileList: []
    }
  },
  computed: {
    limitUpload () {
      return Number(this.limit)
    }
  },
  methods: {
    //
    clearFiles () {
      this.$refs.upload.clearFiles()
      this.$emit('input', [])
      this.fileChange()
    },
    // 获取本组件的上传状态
    isUploading () {
      return this.uploadLoading
    },
    fileRemove (file) {
      this.$emit('input', this.value.filter(f => {
        return f.id !== file.id
      }))
      this.fileChange()
    },
    filePreview (file) { },
    onBeforeUpload (file) {
      // 文件大小限制
      if (file.size / 1024 > this.limitSize) {
        sendMessage({
          cmd: 'messageTips',
          type: 'warning',
          message: `仅支持上传：${this.limitSize >= 1024 ? ((this.limitSize / 1024) + 'MB') : (this.limitSize + 'kb')}以内的文件`
        })
        return false
      }
      // 文件类型限制
      const fileType = '.' + file.name.split('.')[file.name.split('.').length - 1].toLowerCase()
      if (!this.accept.includes(fileType)) {
        let footer = ''
        let header = ''
        switch (this.accept.length) {
          case 0:
            return false
          case 1:
            header = this.accept[0].replace(/[.]/g, '')
            break
          case 2:
            header = this.accept.join('、').replace(/[.]/g, '')
            break
          default:
            header = this.accept.slice(0, this.accept.length - 1).join('、').replace(/[.]/g, '')
            footer = `或${this.accept[this.accept.length - 1]}`.replace(/[.]/g, '')
            break
        }
        sendMessage({
          cmd: 'messageTips',
          type: 'warning',
          message: `仅支持上传：${header}${footer}文件`
        })
        return false
      }
      // 文件个数限制
      const {
        limitErrorMes,
        limitUpload,
        value
      } = this
      if (value.length >= limitUpload) {
        sendMessage({
          cmd: 'messageTips',
          type: 'warning',
          message: limitErrorMes || `当前文件数量超过了最大限制${this.limit}个`
        })
        return false
      }
      if (this.proxyCheck && typeof this.proxyCheck === 'function') {
        return new Promise((resolve, reject) => {
          this.proxyCheck().then(() => {
            resolve()
          }).catch(() => {
            reject()
          })
        })
      }
    },
    uploadStart (file) {
      this.uploadLoading = true
      const time = new Date().getTime()
      const u = {
        [this.name || 'files']: file.file,
        dir: this.dir,
        type: '3'
      }
      const postData = {
        cmd: "iframeGetData",
        params: {
          api: [{
            "fileUploadPublic": {
              files: file.file,
              type: 1,
              dir: 'suit_process'
            }
          }],
          current: time
        }
      }
      sendMessage(postData)
      eventHandler.$on('fileUploadPublic', res => {
        if (time !== res.from.current) return
        if (res.error) {
          // this.$emit('input', this.value.slice(0, this.value.length - 1))
          this.uploadLoading = false
          return
        }
        const {
          data
        } = res.data
        if (!data || data.length === 0) {
          sendMessage({
            cmd: 'messageTips',
            type: 'error',
            message: '上传无返回无结果'
          })
          // this.$emit('input', this.value.slice(0, this.value.length - 1))
          this.uploadLoading = false
          return
        }
        const keys = Object.keys(this.mapping)
        const files = res.data.data.map(item => {
          const result = {}
          keys.forEach(key => {
            result[key] = item[this.mapping[key]] || ''
          })
          return {
            ...result,
            ...item,
            ...this.extraParams
          }
        })
        this.$emit('uploaded', files)
        this.handleUploadSuccess(files)
        this.uploadLoading = false
        eventHandler.$off('fileUploadPublic')
      })
    },
    handleUploadSuccess (files) {
      // 上传成功处理
      if (!this.mulipte) {
        this.$emit('input', files)
      } else {
        this.$emit('input', this.value.concat(files))
      }
      this.fileChange()
    },
    fileChange () {
      this.$emit('change', this.value)
    }
  }
}
