const StepsForm = {
  name: 'StepsForm',
  template: `
    <div class="w_steps_form" :id="id">
    <div v-if="isStepsForm" class="w_steps_form_header box-resolve-screen">
      <sf-step :steps="steps" :current-step="currentStep"></sf-step>
    </div>
    <div v-if="breadList.length" class="w_steps_bread">
      <div class="w_steps_bread__content box-resolve-screen">
        <span class="w_steps_bread__tip">当前位置：</span>
        <div
          v-for="(bread, index) in breadList"
          :class="{
           'steps-form--bread__item': true,
           'steps-form--bread__last': index === breadList.length - 1,
           'steps-form--bread__disabled': !bread.redirect && bread.back !== true
          }">
           <span @click.stop="breadRouterGo(bread)" class="steps-form--bread__text">{{ bread.name }}</span>
           <i class="el-icon el-icon-arrow-right bread-connect" v-if="index < breadList.length - 1"></i>
        </div>
      </div>
    </div>
    <el-form class="el-form-steps" ref="stepForm" id="stepForm" :show-message="!disabled" :hide-required-asterisk="disabled" label-position="right" :model="model" label-width="auto" :rules="rules" @validate="validateEvent">
      <div class="w_steps_form_content box-resolve-screen">
        <template v-for="(step, index) in steps">
         <slot v-if="$slots['step_tips_' + (index + 1)] && currentStep === index" :name="'step_tips_' + (index + 1)" />
          <div v-if="currentStep === index" :key="index" :style="step.bodyStyle" :class="['w_steps_form_step', 'w_steps_form_step' + (index + 1)]">
            <template v-for="(item, stepIndex) in step.keys">
              <el-form-item
                 v-if="$slots[item.prop]"
                 :key="stepIndex"
                 :label-width="item.labelWidth || (itemLabel(item) ? '120px': '0px')"
                 :class="['w_steps_form_item', item.customClass || '']"
                 :label="itemLabel(item)"
                 :prop="item.prop"
                 :rules="item.rules || null"
                >
                <!--                <slot slot="label" :title="item.label" :name="item.prop + '_label'"></slot>-->
                <slot :name="item.prop" />
              </el-form-item>
            </template>
            <div class="w_steps_form_option">
              <el-button v-if="showPrevStep && isStepsForm" @click.stop="prevStep">上一{{ stepButtonText }}</el-button>
              <el-button v-if="showNextStep && isStepsForm" type="primary" @click.stop="nextStep">下一{{ stepButtonText }}</el-button>
              <el-button v-if="showSubmit && !disabled" type="primary" @click="submitStepForm">提交</el-button>
              <el-button v-if="currentStep > getOnlyDisplayStep.length && !disabled && showSave" type="primary" @click="handleSave">{{ showSubmit ? '保存并返回' : '保存' }}</el-button>
              <el-button v-if="currentStep === getOnlyDisplayStep.length && !disabled && showSave" @click="handleCancel">取消</el-button>
           </div>
          </div>
        </template>
      </div>
    </el-form>
  </div>`,
  props: {
    rules: {
      type: Object,
      default() {
        return {}
      }
    },
    model: {
      type: Object, default() {
        return {}
      }
    },
    // [
    //  { keys: [], title: [] }
    // ]
    steps: {
      type: Array,
      default() { return [] }
    },
    disabled: {
      type: Boolean,
      default: false
    },
    beforeNextStep: {
      type: Function
    },
    showSave: {
      type: Boolean,
      default: true
    },
    breadList: {
      type: Array,
      default() {
        return [{ name: '' }]
      }
    }
  },
  data() {
    return {
      currentStep: 0,
      id: new Date().getTime()
    }
  },
  created() {
    this.currentStep = this.getOnlyDisplayStep.length
  },
  computed: {
    isScope() {
      return scope => {
        console.log(scope)
      }
    },
    showPrevStep() {
      return this.currentStep !== this.getOnlyDisplayStep.length
    },
    showNextStep() {
      return this.currentStep < this.steps.length - 1
    },
    showSubmit() {
      return this.currentStep === this.steps.length - 1
    },
    isStepsForm() {
      return $validate.isArray(this.realSteps) && this.steps.length > 1
    },
    realSteps() {
      return this.steps.filter(step => step.type !== 'onlyDisplay')
    },
    getOnlyDisplayStep() {
      return this.steps.filter(step => step.type === 'onlyDisplay')
    },
    stepButtonText() {
      return this.disabled ? '页' : '步'
    }
  },
  watch: {
    currentStep(val) {
      this.$emit('stepChange', val)
    }
  },
  methods: {
    getHeight() {
      return document.getElementById(this.id).clientHeight
    },
    itemLabel(item) {
      return item.label ? item.label + '：' : ''
    },
    resetFields() {
      this.$refs.stepForm.resetFields.apply(this, arguments)
    },
    validateField(field) {
      this.$refs.stepForm.validateField(field)
    },
    clearValidate() {
      this.$refs.stepForm.clearValidate.apply(this, arguments)
    },
    validateEvent(prop, pass, errMsg) {
      this.$emit('validate', { prop, pass, errMsg })
    },
    cancelSubmit() {
      this.$emit('cancel')
    },
    prevStep() {
      this.currentStep -= 1
      this.$emit('prevStep', this.currentStep)
    },
    doNext() {
      this.currentStep += 1
      this.$emit('nextstep', this.currentStep)
    },
    nextStep() {
      if(this.disabled) {
        this.doNext()
        return
      }
      this.$refs.stepForm.validate((pass) => {
        if (pass) {
          if(!this.beforeNextStep || typeof this.beforeNextStep !== 'function') {
            this.doNext()
          } else {
           this.beforeNextStep(this.currentStep, this.doNext)
          }
        } else {
          return false
        }
      })
    },
    submitStepForm() {
      this.$refs.stepForm.validate((pass) => {
        if (pass) {
          this.$emit('submit')
        } else {
          return false
        }
      })
    },
    setStep(step) {
      this.currentStep = step
    },
    getStep() {
      return this.currentStep
    },
    handleCancel() {
      this.$emit('cancel')
    },
    handleSave() {
      this.$emit('save')
    },
    breadRouterGo({ redirect, back }) {
      if(!redirect && back !== true) {
        return
      }
      sendMessage({
        cmd: 'iframeRouterGo',
        redirect,
        back
      })
    }
  }
}
