const SfDatePicker = {
  name: 'SfDatePicker',
  template: ` <van-popup get-container="body" :close-on-click-overlay="false" @click-overlay="close()" v-model="show" round position="bottom" @open="setDateValue">
    <section class="sf-datePicker">
      <div class="sf-datePicker--header">
        <div class="sf-datePicker--title">
          {{ parseDateFormat(dateValue, headerFormatMap[type]) }}
        </div>
        <van-icon name="cross" @click.stop="close"></van-icon>
      </div>
      <div class="sf-datePicker--body">
        <van-datetime-picker
          :key="show" 
          v-model="dateValue"
          :show-toolbar="false"
          :type="type"
          :formatter="formatter"
          :min-date="minDate"
          :max-date="maxDate"
        />
      </div>
      <div class="sf-datePicker--footer">
        <van-button
          plain
          round
          class="mg-right"
          native-type="button"
          type="default"
          @click.stop.native="handleCancel"
        >取消</van-button>
        <van-button
          round
          class="mg-left"
          native-type="button"
          type="info"
          @click.stop.native="handleConfirm"
        >确定</van-button>
      </div>
    </section>
  </van-popup>`,
  props: {
    show: {
      type: Boolean,
      default: () => false
    },
    value: {
      type: String,
      default: () => ''
    },
    valueFormat: {
      type: String,
      default: () => 'YYYY-MM-DD'
    },
    // 选择格式，默认年月日
    type: {
      type: String,
      default: 'date'
    },
    minDate: {
      type: Date
    },
    maxDate: {
      type: Date,
      default() {
        return new Date()
      }
    },
    headerFormat: {
      type: String,
      default() {
        return undefined
      }
    },
    customFormat: {
      type: [Function, undefined]
    },
    defaultValue: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      dateValue: undefined,
      headerFormatMap: {
        date: 'YYYY年MM月DD日',
        time: 'YYYY年MM月DD日 HH时mm分',
        'year-month': 'YYYY年MM月',
        'month-day': 'MM月DD日',
        datehour: 'YYYY年MM月DD日 HH时'
      },
      formatValue: {
        date: 'YYYY/MM/DD',
        time: 'YYYY/MM/DD HH:mm',
        'year-month': 'YYYY/MM',
        'month-day': 'MM/DD',
        datehour: 'YYYY/MM/DD HH'
      }
    }
  },
  computed: {
    parseDateFormat() {
      return (date, format) => {
        if (!date) {
          return '请选择日期'
        }
        return moment(date).format(format)
      }
    }
  },
  created() {
    this.setDateValue()
  },
  methods: {
    setDateValue() {
      if (this.value) this.dateValue = new Date(moment(this.value).format(this.formatValue[this.type]))
      else if ($validate.isDateISO(this.defaultValue)) this.dateValue = new Date(this.defaultValue)
      else this.dateValue = new Date()
    },
    handleClose() {
      this.$emit('close')
      this.close()
    },
    handleCancel() {
      this.$emit('cancel')
      this.close()
    },
    format() {
      return moment(this.dateValue).format(this.valueFormat)
    },
    handleConfirm() {
      this.$emit('input', this.format())
      this.$emit('confirm', this.format())
      this.close()
    },
    close() {
      this.$emit('update:show', false)
    },
    formatter(type, value) {
      if (type === 'year') {
        return `${value}`
      } else if (type === 'month') {
        return `${value}`
      } else if (type === 'day') {
        return `${value}`
      } else if (type === 'hour') {
        return `${value}`
      } else if (type === 'minute') {
        return `${value}`
      } else if (type === 'second') {
        return `${value}`
      }
      return value
    }
  }
}
