const SfUploader = {
    name: 'SfUploader',
    template: `<div class="sf-uploader sf-uploader--card">
               <van-uploader
                ref="sfUploader"
                :accept="accept"
                :id="id"
                style="display:none"
                :disabled="disabled"
                :preview-image="false"
                :before-read="fileBeforeRead"
                :after-read="signUsePictureStartUpload">
              </van-uploader>
                <div class="sf-uploader-content">
<!--                 上传按钮 -->
                  <div class="sf-uploader__wrapper--card">
                    <template v-for="file in imageList">
                      <!--                    卡片式 上传-->
                      <div class="sf-image-list--card"
                           :key="file.id">
                        <div class="image_wrapper">
                          <van-image
                            :class="['upload_res', isImageFile(file) ? 'upload_image' : 'upload_file']"
                            :src="file.url"
                          ></van-image>
                          <img
                            class="sf-uploader__delete"
                            @click.stop="removeSignFile(file)"
                            src="./suitStatic/image/close-circle.png" />
                        </div>
                      </div>
                    </template>
                    <div
                      v-if="value.length < limit"
                      v-show="!disabled"
                      class="sf-image-list--card"
                      @click.stop="selectUploadType"
                    >
                      <div :class="['upload_icon', 'uploadIcon', 'flexCenter']">
                        <img class="upload_img" src="./suitStatic/image/add.png" alt="">
                        <span class="upload_text">{{uploadText}}</span>
                      </div>
                    </div>
                    <div v-for="file in fileList" class="sf-image-list--ul" :key="file.id">
                      {{ file.originalName || file.evidencFileName }}
                      <img
                        class="sf-uploader__delete"
                        @click.stop="removeSignFile(file)"
                        src="./suitStatic/image/close-circle.png" />
                    </div>
                  </div>
                </div>
                <div class="sf-uploader-tips" style="color: #999">
                  支持：.doc,.docx,.rar,.zip,.jpeg,.jpg,.png,.pdf,.xlsx,.xls
                </div>
            </div>`,
    props: {
        value: {
            type: Array,
            default: function () {
                return []
            }
        },
        disabled: {
            type: Boolean,
            default: function () {
                return false
            }
        },
        dir: {
          type: String,
          default: 'public'
        },
        limit: {
            type: Number,
            default: function () {
                return 20
            }
        },
        // 文件上传成功时，给上传成功的文件添加额外的参数
        extraParams: {
           type: Object,
           default: () => {}
        },
        // 文件上传成功时，文件列表添加额外的属性映射
        mapping: {
            type: Object,
            default: () => {}
        },
        current: {
            type: String,
            default: () => 'current'
        },
        uploadText: {
            type: String,
            default: '上传材料'
        },
        mutiple: {
            type: Boolean,
            default: () => true
        },
        limitSize: {
            type: Number,
            default: 10240
        },
        accept: {
            type: String,
            default: 'image/*,.docx,.pdf,.doc,.xlsx,.xls,.zip,.rar'
        }
    },
    created() {
      this.id = new Date().getTime()
    },
    data() {
      return {
          id: null
      }
    },
    computed: {
        isImageFile() {
          return file => {
              const fileType = file.fileType || file.originalName.split('.')[file.originalName.split('.').length - 1]
              return ['png', 'jpg', 'jpeg', 'bmp','JPG', 'JPEG', 'PNG', 'BMP'].includes(fileType)
          }
        },
        imageList() {
            return this.value.filter(file => this.isImageFile(file))
        },
        fileList() {
            return this.value.filter(file => !this.isImageFile(file))
        }
    },
    methods: {
        normalTips(message) {
            sendMessage({
                cmd: 'warnInfo',
                params: {
                    type: 'text',
                    message
                }
            })
        },
        fileBeforeRead(file) {
          // 获取kb
          const size = file.size / 1024, { limitSize } = this
          const fileType = '.' + (file.name.split('.')[file.name.split('.').length - 1]).toLocaleLowerCase()
          const acceptList = ['.png', '.jpg', '.pdf', '.jpeg', '.xls', '.xlsx', '.zip', '.rar', '.doc', '.docx']
          if(!acceptList.includes(fileType)) {
              this.normalTips(`仅支持上传：${acceptList.join(',')}类型的的文件`)
              return false
          }
          if(size > limitSize) {
             const tips = limitSize > 1024 ? (limitSize / 1024) + 'MB' : limitSize + 'KB'
             this.normalTips(`仅支持上传：${tips}以内的文件`)
             return false
          }
          return true
        },
        signUsePictureStartUpload(file) {
            const current = new Date().getTime()
            const postData = {
                cmd: "iframeGetData",
                params: {
                    api: [{"fileUploadPublic": { files: file.file, type: 1, dir: this.dir} }],
                    current: current
                }
            }
            sendMessage(postData)
            eventHandler.$on('fileUploadPublic', res => {
                if(current !== res.from.current) { return }
                if(res.data.data.length === 0) {
                    Notify({ type: 'danger', message: '上传无返回结果', duration: 2000 });
                    return
                }
                const keys = Object.keys(this.mapping)
                const result = {}
                const files = res.data.data.map(item => {
                   keys.forEach(key => {
                     result[key] = item[this.mapping[key]] || ''
                   })
                   return {
                       ...result,
                       ...item,
                       ...this.extraParams
                   }
                })
                console.log(files, 'files')
                if(this.mutiple) {
                    this.$emit('input', this.value.concat(files))
                } else {
                    this.$emit('input', files)
                }
            })
        },
        selectUploadType() {
          const { id } = this
          document.getElementById(id) && document.getElementById(id).click()
        },
        removeSignFile(file) {
            this.$emit('input', this.value.filter(F => F.id !== file.id))
        }
    }
}
