const StepForm = {
  name: 'StepForm',
  template: `<div class="w-steps_form">
    <div class="steps_header">
     <div class="w-steps_from_step">
      <van-steps :active="currentStep" inactive-color="#fff" active-color="#fff" class="van-steps_blue van-steps_revers">
        <van-step
         :class="{ 'van-step__last': index === steps.length - 1, 'van-step__first': index === 0 }" 
         v-for="(step, index) in steps"
         :key="step.key"
         :data-key="step.key"
        >
         <div slot="active-icon" class="circle white"></div>
         <div slot="inactive-icon" class="circle blue"></div>
        {{ step.title }}
        </van-step>
      </van-steps>
    </div>
    </div>
    <div class="w-steps_form_content">
      <van-form
        input-align="right"  
        ref="stepForm"
        validate-first
        scroll-to-error
        :show-error-message="true"
        @failed="validateFailed"
      >
        
        <section v-for="(step, index) in steps">
          <div v-if="currentStep === index" :key="index" class="w-steps_form_isStep">
            <slot :name="'step_' + (index + 1)">
               <template v-if="step.props && step.props.length">
                <slot v-for="prop in step.props" :name="prop" :key="prop" v-if="$slots[prop]"></slot>
              </template>
            </slot>
          </div>
        </section>
      </van-form>
      <div class="w-steps_form_options">
        <van-button
          v-if="showPrevStep && isStepsForm"
          style="flex: 1;margin: 0 var(--8pxToRem)"
          type="info"
          round
          native-type="button"
          @click.stop="prevStep"
        >上一步</van-button>
        <van-button
         :disabled="disabledCurrent"
          v-if="showNextStep && isStepsForm"
         style="flex: 1;margin: 0 var(--8pxToRem)"
          type="info" 
          round
          native-type="button"
          @click="nextStep"
        >下一步</van-button>
        <van-button
          v-if="showSubmit && !disabled"
          style="flex: 1;margin: 0 var(--8pxToRem)"
          native-type="button"
          type="info"
          round
          @click="submitLastStep"
         >提交</van-button>
        <van-button
            style="flex: 1;margin: 0 var(--8pxToRem);white-space: nowrap"
            type="default"
            native-type="button"
            round
            v-if="currentStep > getOnlyDisplayStepsLength && !disabled && showSave"
            @click="handleSave">{{ showSubmit ? '保存并返回' : '保存' }}
        </van-button>
        <van-button
            style="flex: 1;margin: 0 var(--8pxToRem)"
            type="default"
            native-type="button"
            round
            v-if="currentStep === getOnlyDisplayStepsLength && !disabled && showSave"
            @click="handleCancel">取消
        </van-button>
    </div>
    </div>
  </div>`,
  props: {
    rules: {
      type: Object,
      default() {
        return {}
      }
    },
    showSave: {
      type: Boolean,
      default: true
    },
    steps: {
      type: Array,
      default() {
        return [
          { title: '基本信息' },
          { title: '家庭信息' },
          { title: '社交信息' },
          { title: '本人照片' }
        ]
      }
    },
    disabled: {
      type: Boolean,
      default: false
    },
    beforeNextStep: {
      type: Function
    }
  },
  created() {
    this.currentStep = this.getOnlyDisplayStepsLength
  },
  data() {
    return {
      currentStep: 1
    }
  },
  computed: {
    showPrevStep() {
      return this.currentStep !== this.getOnlyDisplayStepsLength
    },
    showNextStep() {
      return this.currentStep < this.steps.length - 1
    },
    showSubmit() {
      return this.currentStep === this.steps.length - 1
    },
    isStepsForm() {
      return this.steps instanceof Array && this.steps.length > 1
    },
    disabledCurrent() {
      const current = this.steps[this.currentStep]
      return this.isFunction(current.disabled) ? current.disabled() : false
    },
    getOnlyDisplayStepsLength() {
      return this.steps.filter(s => s.type === 'onlyDisplay').length
    }
  },
  methods: {
    isFunction(value) {
      if ([NaN, undefined, null, 0, ''].includes(value)) { return false }
      return typeof value === 'function'
    },
    resetFields() {
      this.$refs.stepForm.resetValidation.apply(this, arguments)
    },
    validateField() {
      return this.$refs.stepForm.validate.apply(this, arguments)
    },
    validate() {
      return this.$refs.stepForm.validate.apply(this, arguments)
    },
    clearValidate() {
      this.$refs.stepForm.resetValidation.apply(this, arguments)
    },
    validateFailed() {
      // scrollFistErrorAndShowToast()
    },
    doNext() {
      this.currentStep++
      this.$emit('step', { prevStep: this.currentStep - 1, currentStep: this.currentStep })
    },
    nextStep() {
      let fieldKeys = this.steps[this.currentStep].needValidateKeys
      if (!(fieldKeys instanceof Array)) fieldKeys = []
      if(this.disabled) {
        if(!this.beforeNextStep || typeof this.beforeNextStep !== 'function') {
          this.doNext()
        } else {
          this.beforeNextStep(this.currentStep, this.doNext)
        }
      } else {
        this.validate().then(() => {
          if(!this.beforeNextStep || typeof this.beforeNextStep !== 'function') {
            this.doNext()
          } else {
            this.beforeNextStep(this.currentStep, this.doNext)
          }
        }).catch((e) => {
          scrollFistErrorAndShowToast()
          return false
        })
      }
    },
    prevStep() {
      this.currentStep -= 1
      this.$emit('prevStep', { prevStep: this.currentStep - 1, currentStep: this.currentStep })
    },
    submitLastStep() {
      let fieldKeys = this.steps[this.currentStep].needValidateKeys
      if (!(fieldKeys instanceof Array)) fieldKeys = []
      this.validate().then(() => {
        this.$emit('submit')
      }).catch(() => {
        scrollFistErrorAndShowToast()
      })
    },
    setStep(step) {
      this.currentStep = step
    },
    getStep() {
      return this.currentStep
    },
    handleCancel() {
      this.$emit('cancel')
    },
    handleSave() {
      this.$emit('save')
    }
  }
}
