'use strict';
var useSettings = function () {
  return {
    caseSteps: {
      '': [],
      undefined: [],
      null: [],
      // 民事一审
      'MSYS': [
        { title: '诉讼材料', props: ['material'], key: 'MSYS-m'},
        { title: '案件信息', props: ['caseBasic'], key: 'MSYS-i' }
      ],
      // 宣告死亡
      'XGSZSW': [
        { title: '案件信息', props: ['caseBasic'], key: 'XGSZSW-i' },
        { title: '诉讼材料', props: ['material'], key: 'XGSZSW-m'}
      ],
      // 行为能力认定
      'XWNLRD': [
        { title: '案件信息', props: ['caseBasic'], key: 'XWNLRD-i' },
        { title: '诉讼材料', props: ['material'], key: 'XWNLRD-m'}
      ],
      // 监护关系变更
      'JHGXBG': [
        { title: '案件信息', props: ['caseBasic'], key: 'JHGXBG-i' },
        { title: '诉讼材料', props: ['material'], key: 'JHGXBG-m'}
      ],
      //  实现物品担保权
      'SXDBWQ': [
        { title: '案件信息', props: ['caseBasic'], key: 'SXDBWQ-i' },
        { title: '诉讼材料', props: ['material'], key: 'SXDBWQ-m'}
      ],
      //  调解协议司法确认
      'TJXYSFQR': [
        { title: '案件信息', props: ['caseBasic'], key: 'TJXYSFQR-i' },
        { title: '诉讼材料', props: ['material'], key: 'TJXYSFQR-m'}
      ],
      // 监护人指定异议
      'JHRZDYY': [
        { title: '案件信息', props: ['caseBasic'], key: 'JHRZDYY-i' },
        { title: '诉讼材料', props: ['material'], key: 'JHRZDYY-m'}
      ],
      //  起诉（行政）
      'XZYS': [
        { title: '案件信息', props: ['caseBasic'], key: 'XZYS-i' },
        { title: '诉讼材料', props: ['material'], key: 'XZYS-m'}
      ],
      //     自赔
      'FYXWPCYWJGZP': [
        { title: '案件信息', props: ['caseBasic'], key: 'FYXWPCYWJGZP-i' },
        { title: '诉讼材料', props: ['material'], key: 'FYXWPCYWJGZP-m'}
      ],
    },
    //  第二部-当事人信息配置项
    casePerson: {
      '': { 0: {}, 1: {}, 2: {}, 3: {}, 4: {} },
      'undefined': { 0: {}, 1: {}, 2: {}, 3: {}, 4: {} },
      'null': { 0: {}, 1: {}, 2: {}, 3: {}, 4: {} },
      //  民事一审（起诉）
      'MSYS': {
        0: { show: true, type: '0', required: true, label: '原告当事人' },
        1: { show: true, type: '1', required: true, label: '被告当事人' },
        2: { show: true, type: '2', label: '第三人' },
        3: { show: true, type: '3', label: '原告代理人' },
        4: { show: true, type: '4', label: '证人' }
      },
      //  宣告死亡
      'XGSZSW': {
        0: { show: true, type: '5', required: true, label: '申请人' },
        1: { show: true, type: '6', required: true, label: '被申请人' },
        2: { show: false },
        3: { show: true, type: '7', label: '申请人代理人' },
        4: { show: true, type: '4', label: '证人' }
      },
      //  行为能力认定
      'XWNLRD': {
        0: { show: true, type: '8', required: true, label: '申请人' },
        1: { show: true, type: '9', required: true, label: '被申请人' },
        2: { show: false },
        3: { show: true, type: '7', label: '申请人代理人' },
        4: { show: true, type: '4', label: '证人' }
      },
      //  监护人指定异议
      'JHRZDYY': {
        0: { show: true, type: '10', required: true, label: '异议人' },
        1: { show: false },
        2: { show: false },
        3: { show: true, type: '11', label: '异议人代理人' },
        4: { show: true, type: '4', label: '证人' }
      },
      // 监护关系变更
      'JHGXBG': {
        0: { show: true, type: '12', required: true, label: '起诉人' },
        1: { show: true, type: '13', required: true, label: '被诉监护人' },
        2: { show: false },
        3: { show: true, type: '14', label: '起诉人代理人' },
        4: { show: true, type: '4', label: '证人' }
      },
      //  实现物品担保权
      'SXDBWQ': {
        0: { show: true, type: '15', required: true, label: '申请人' },
        1: { show: true, type: '6', required: true, label: '被申请人' },
        2: { show: false },
        3: { show: true, type: '7', label: '申请人代理人' },
        4: { show: true, type: '4', label: '证人' }
      },
      //  调解协议司法确认
      'TJXYSFQR': {
        0: { show: true, type: '5', required: true, label: '申请人' },
        1: { show: false },
        2: { show: false },
        3: { show: true, type: '7', label: '申请人代理人' },
        4: { show: true, type: '4', label: '证人' }
      },
      //  起诉（行政）
      'XZYS': {
        0: { show: true, type: '0', required: true, label: '原告当事人' },
        1: { show: true, type: '1', required: true, label: '被告当事人' },
        2: { show: true, type: '2', label: '第三人' },
        3: { show: true, type: '3', label: '原告代理人' },
        4: { show: true, type: '4', label: '证人' }
      },
      //     自赔
      'FYXWPCYWJGZP': {
        0: { show: true, type: '16', required: true, label: '赔偿请求人' },
        1: { show: true, type: '17', required: true, label: '赔偿义务机关', initPeopleType: '1', limitSize: 1 },
        2: { show: false, type: '2' },
        3: { show: true, type: '18', label: '代理人' },
        4: { show: false, type: '4' }
      },
      // 执行立案
      'ZXLA': {
        0: { show: true, type: '5', required: true, label: '申请人' },
        1: { show: true, type: '6', required: true, label: '被申请人' },
        2: { show: true, type: '2', label: '第三人' },
        3: { show: true, type: '7', label: '申请人代理人' },
        4: { show: true, type: '4', label: '证人' }
      }
    },
    // 第二步---当事人展示信息
    casePersonDisplay: {
      '': { 0: {}, 1: {}, 2: {}, 3: {}, 4: {} },
      'undefined': { 0: {}, 1: {}, 2: {}, 3: {}, 4: {} },
      'null': { 0: {}, 1: {}, 2: {}, 3: {}, 4: {} },
      //  民事一审（起诉）
      'MSYS': {
        '0': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '1': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '2': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '3': [
          { label: '被代理人', value: 'part_name', width: '100%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '100%', indent: '' },
          { label: '代理人类型', value: 'agentTypeName', width: '100%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ],
        '4': [
          { label: '有利方', value: 'part_name', width: '50%', indent: '' },
          { label: '性别', value: 'sexName', width: '50%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '50%', indent: '' },
          { label: '出庭作证', value: 'inCourtName', width: '50%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ]
      },
      //  宣告死亡
      'XGSZSW': {
        '0': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '1': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '2': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '3': [
          { label: '被代理人', value: 'part_name', width: '100%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '100%', indent: '' },
          { label: '代理人类型', value: 'agentTypeName', width: '100%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ],
        '4': [
          { label: '有利方', value: 'part_name', width: '50%', indent: '' },
          { label: '性别', value: 'sexName', width: '50%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '50%', indent: '' },
          { label: '出庭作证', value: 'inCourtName', width: '50%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ]
      },
      //  行为能力认定
      'XWNLRD': {
        '0': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '1': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '2': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '3': [
          { label: '被代理人', value: 'part_name', width: '100%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '100%', indent: '' },
          { label: '代理人类型', value: 'agentTypeName', width: '100%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ],
        '4': [
          { label: '有利方', value: 'part_name', width: '50%', indent: '' },
          { label: '性别', value: 'sexName', width: '50%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '50%', indent: '' },
          { label: '出庭作证', value: 'inCourtName', width: '50%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ]
      },
      // 监护关系变更
      'JHGXBG': {
        '0': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '1': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '2': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '3': [
          { label: '被代理人', value: 'part_name', width: '100%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '100%', indent: '' },
          { label: '代理人类型', value: 'agentTypeName', width: '100%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ],
        '4': [
          { label: '有利方', value: 'part_name', width: '50%', indent: '' },
          { label: '性别', value: 'sexName', width: '50%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '50%', indent: '' },
          { label: '出庭作证', value: 'inCourtName', width: '50%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ]
      },
      //  实现物品担保权
      'SXDBWQ': {
        '0': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '1': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '2': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '3': [
          { label: '被代理人', value: 'part_name', width: '100%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '100%', indent: '' },
          { label: '代理人类型', value: 'agentTypeName', width: '100%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ],
        '4': [
          { label: '有利方', value: 'part_name', width: '50%', indent: '' },
          { label: '性别', value: 'sexName', width: '50%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '50%', indent: '' },
          { label: '出庭作证', value: 'inCourtName', width: '50%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ]
      },
      //  调解协议司法确认
      'TJXYSFQR': {
        '0': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '1': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '2': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '3': [
          { label: '被代理人', value: 'part_name', width: '100%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '100%', indent: '' },
          { label: '代理人类型', value: 'agentTypeName', width: '100%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ],
        '4': [
          { label: '有利方', value: 'part_name', width: '50%', indent: '' },
          { label: '性别', value: 'sexName', width: '50%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '50%', indent: '' },
          { label: '出庭作证', value: 'inCourtName', width: '50%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ]
      },
      //  监护人指定异议
      'JHRZDYY': {
        '0': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '1': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '2': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '3': [
          { label: '被代理人', value: 'part_name', width: '100%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '100%', indent: '' },
          { label: '代理人类型', value: 'agentTypeName', width: '100%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ],
        '4': [
          { label: '有利方', value: 'part_name', width: '50%', indent: '' },
          { label: '性别', value: 'sexName', width: '50%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '50%', indent: '' },
          { label: '出庭作证', value: 'inCourtName', width: '50%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ]
      },
      //  起诉（行政）
      'XZYS': {
        '0': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '1': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '2': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '3': [
          { label: '被代理人', value: 'part_name', width: '100%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '100%', indent: '' },
          { label: '代理人类型', value: 'agentTypeName', width: '100%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ],
        '4': [
          { label: '有利方', value: 'part_name', width: '50%', indent: '' },
          { label: '性别', value: 'sexName', width: '50%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '50%', indent: '' },
          { label: '出庭作证', value: 'inCourtName', width: '50%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ]
      },
      //     自赔
      'FYXWPCYWJGZP': {
        '0': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '1': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '2': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '3': [
          { label: '被代理人', value: 'part_name', width: '100%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '100%', indent: '' },
          { label: '代理人类型', value: 'agentTypeName', width: '100%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ],
        '4': [
          { label: '有利方', value: 'part_name', width: '50%', indent: '' },
          { label: '性别', value: 'sexName', width: '50%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '50%', indent: '' },
          { label: '出庭作证', value: 'inCourtName', width: '50%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ]
      },
      //  执行立案
      'ZXLA': {
        '0': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '1': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '2': {
          '0':  [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '民族', value: 'nationName', width: '50%', indent: 'var(--3pxToRem)' },
            { label: '性别', value: 'sexName', width: '50%', indent: ''  },
            { label: '出生日期', value: 'bornDate', width: '50%', indent: 'var(--3pxToRem)' }
          ],
          '1': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '法人', value: 'leaderName', width: '50%', indent: '1em'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' },
          ],
          '2': [
            { label: '电话', value: 'mobilePhone', width: '50%', indent: '' },
            { label: '主要负责人', value: 'leaderName', width: '50%', indent: 'var(--3pxToRem)'  },
            { label: '地址', value: 'applicantDetailedAddress', width: '100%', indent: '' }
          ]
        },
        '3': [
          { label: '被代理人', value: 'part_name', width: '100%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '100%', indent: '' },
          { label: '代理人类型', value: 'agentTypeName', width: '100%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ],
        '4': [
          { label: '有利方', value: 'part_name', width: '50%', indent: '' },
          { label: '性别', value: 'sexName', width: '50%', indent: '' },
          { label: '手机号码', value: 'mobilePhone', width: '50%', indent: '' },
          { label: '出庭作证', value: 'inCourtName', width: '50%', indent: ''  },
          { label: '证件号码', value: 'cardNumber', width: '100%', indent: '' }
        ]
      }
    },
    //  第三步-诉讼材料信息配置项
    caseMaterial: {
      '': { pleadings: {}, casePersonIdentifyFiles: {}, evidenceFiles: {}, evidenceFilesOther: {}, casePersonConfirmFiles: {}, otherFiles: {} },
      'undefined': { pleadings: {}, casePersonIdentifyFiles: {}, evidenceFiles: {}, evidenceFilesOther: {}, casePersonConfirmFiles: {}, otherFiles: {} },
      'null': { pleadings: {}, casePersonIdentifyFiles: {}, evidenceFiles: {}, evidenceFilesOther: {}, casePersonConfirmFiles: {}, otherFiles: {} },
      //  民事一审（起诉）
      'MSYS': {
        pleadings: {  title: '起诉状',  materialClassification: '1', materialClassificationName: '起诉状', apply: '原告', applied: '被告', materialName(y,b) { return `${y}诉${b}的起诉状`  }, casePersonTypeName: { '0': '原告', '1': '被告' }   }, // 起诉状、申请书、国家赔偿申请书
        casePersonIdentifyFiles: { materialClassification: { 0: '2', 1: '3', 2: '17', 3: '18', 4: '19' }, materialClassificationName: { 0: '原告', 1: '被告', 2: '第三人', 3: '原告代理人', 4: '证人' }, require: { 0: true, 1: false, 2: false, 3: true, 4: false } }, // 身份证明材料
        evidenceFiles: { show: true, casePersonTypeName: '原告' }, // 证据材料
        evidenceFilesOther: { show: false, casePersonTypeName: '原告' }, // 证据材料
        casePersonConfirmFiles: { materialClassification: '4', materialClassificationName: '送达地址确认书', casePersonTypeName: '原告' }, // 当事人送达确认书
        otherFiles: { materialType: 'select', casePersonTypeName: { '0': '原告', '1': '被告' }  } // 其他材料
      },
      //  宣告死亡
      'XGSZSW': {
        pleadings: { title: '申请书',  materialClassification: '1', materialClassificationName: '申请书', apply: '申请人', applied: '被申请人', materialName(y,b) { return `${y}对${b}的申请书`  }, casePersonTypeName: { '0': '申请人', '1': '被申请人' }   }, // 起诉状、申请书、国家赔偿申请书
        casePersonIdentifyFiles: { title: '身份证明材料',  materialClassification: { 0: '2', 1: '3', 2: '17', 3: '18', 4: '19' }, materialClassificationName: { 0: '申请人', 1: '被申请人', 2: '', 3: '申请人代理人', 4: '证人' }, require: { 0: true, 1: false, 2: false, 3: true, 4: false } }, // 身份证明材料
        evidenceFiles: { show: false, casePersonTypeName: '申请人' }, // 证据材料
        evidenceFilesOther: { show: true, casePersonTypeName: '申请人' }, // 证据材料
        casePersonConfirmFiles: { materialClassification: '4', materialClassificationName: '送达地址确认书', casePersonTypeName: '申请人' }, // 当事人送达确认书
        otherFiles: { materialType: 'input', casePersonTypeName: { '0': '申请人', '1': '被申请人' } } // 其他材料
      },
      //  行为能力认定
      'XWNLRD': {
        pleadings: { title: '申请书',  materialClassification: '1', materialClassificationName: '申请书', apply: '申请人', applied: '被申请人', materialName(y,b) { return `${y}对${b}的申请书`  }, casePersonTypeName: { '0': '申请人', '1': '被申请人' }    }, // 起诉状、申请书、国家赔偿申请书
        casePersonIdentifyFiles: { title: '身份证明材料',  materialClassification: { 0: '2', 1: '3', 2: '17', 3: '18', 4: '19' }, materialClassificationName: { 0: '申请人', 1: '被申请人', 2: '', 3: '申请人代理人', 4: '证人' }, require: { 0: true, 1: false, 2: false, 3: true, 4: false } }, // 身份证明材料
        evidenceFiles: { show: false, casePersonTypeName: '申请人' }, // 证据材料
        evidenceFilesOther: { show: true, casePersonTypeName: '申请人' }, // 证据材料
        casePersonConfirmFiles: { materialClassification: '4', materialClassificationName: '送达地址确认书', casePersonTypeName: '申请人' }, // 当事人送达确认书
        otherFiles: { materialType: 'input', casePersonTypeName: { '0': '申请人', '1': '被申请人' } } // 其他材料
      },
      // 监护关系变更
      'JHGXBG': {
        pleadings: { title: '申请书',  materialClassification: '1', materialClassificationName: '申请书', apply: '起诉人', applied: '被诉监护人', materialName(y,b) { return `${y}对${b}的申请书`  }, casePersonTypeName: { '0': '起诉人', '1': '被诉监护人' }    }, // 起诉状、申请书、国家赔偿申请书
        casePersonIdentifyFiles: { title: '身份证明材料',  materialClassification: { 0: '2', 1: '3', 2: '17', 3: '18', 4: '19' }, materialClassificationName: { 0: '起诉人', 1: '被诉监护人', 2: '', 3: '起诉人代理人', 4: '证人' }, require: { 0: true, 1: false, 2: false, 3: true, 4: false } }, // 身份证明材料
        evidenceFiles: { show: false, casePersonTypeName: '起诉人' }, // 证据材料
        evidenceFilesOther: { show: true, casePersonTypeName: '起诉人' }, // 证据材料
        casePersonConfirmFiles: { materialClassification: '4', materialClassificationName: '送达地址确认书', casePersonTypeName: '起诉人' }, // 当事人送达确认书
        otherFiles: { materialType: 'input', casePersonTypeName: { '0': '起诉人', '1': '被诉监护人' } } // 其他材料
      },
      //  实现物品担保权
      'SXDBWQ': {
        pleadings: { title: '申请书',  materialClassification: '1', materialClassificationName: '申请书', apply: '申请人', applied: '被申请人', materialName(y,b) { return `${y}对${b}的申请书`  }, casePersonTypeName: { '0': '申请人', '1': '被申请人' }   }, // 起诉状、申请书、国家赔偿申请书
        casePersonIdentifyFiles: { title: '身份证明材料',  materialClassification: { 0: '2', 1: '3', 2: '17', 3: '18', 4: '19' }, materialClassificationName: { 0: '申请人', 1: '被申请人', 2: '', 3: '申请人代理人', 4: '证人' }, require: { 0: true, 1: false, 2: false, 3: true, 4: false } }, // 身份证明材料
        evidenceFiles: { show: false, casePersonTypeName: '申请人' }, // 证据材料
        evidenceFilesOther: { show: true, casePersonTypeName: '申请人' }, // 证据材料
        casePersonConfirmFiles: { materialClassification: '4', materialClassificationName: '送达地址确认书', casePersonTypeName: '申请人' }, // 当事人送达确认书
        otherFiles: { materialType: 'input', casePersonTypeName: { '0': '申请人', '1': '被申请人' } } // 其他材料
      },
      //  调解协议司法确认
      'TJXYSFQR': {
        pleadings: { title: '申请书',  materialClassification: '1', materialClassificationName: '申请书', apply: '申请人', materialName(y,b) { return `${y}的申请书`  }, casePersonTypeName: { '0': '申请人', '1': '被申请人' }    }, // 起诉状、申请书、国家赔偿申请书
        casePersonIdentifyFiles: { title: '身份证明材料',  materialClassification: { 0: '2', 1: '3', 2: '17', 3: '18', 4: '19' }, materialClassificationName: { 0: '申请人', 1: '被申请人', 2: '', 3: '申请人代理人', 4: '证人' }, require: { 0: true, 1: false, 2: false, 3: true, 4: false } }, // 身份证明材料
        evidenceFiles: { show: false, casePersonTypeName: '申请人' }, // 证据材料
        evidenceFilesOther: { show: true, casePersonTypeName: '申请人' }, // 证据材料
        casePersonConfirmFiles: { materialClassification: '4', materialClassificationName: '送达地址确认书', casePersonTypeName: '申请人' }, // 当事人送达确认书
        otherFiles: { materialType: 'input', casePersonTypeName: { '0': '申请人', '1': '被申请人' } } // 其他材料
      },
      //  监护人指定异议
      'JHRZDYY': {
        pleadings: { title: '申请书',  materialClassification: '1', materialClassificationName: '申请书', apply: '异议人', materialName(y,b) { return `${y}的申请书`  }, casePersonTypeName: { '0': '异议人', '1': '被申请人' }    }, // 起诉状、申请书、国家赔偿申请书
        casePersonIdentifyFiles: { title: '身份证明材料',  materialClassification: { 0: '2', 1: '3', 2: '17', 3: '18', 4: '19' }, materialClassificationName: { 0: '异议人', 1: '', 2: '', 3: '异议人代理人', 4: '证人' }, require: { 0: true, 1: false, 2: false, 3: true, 4: false } }, // 身份证明材料
        evidenceFiles: { show: false, casePersonTypeName: '异议人' }, // 证据材料
        evidenceFilesOther: { show: true, casePersonTypeName: '异议人' }, // 证据材料
        casePersonConfirmFiles: { materialClassification: '4', materialClassificationName: '送达地址确认书', casePersonTypeName: '异议人' }, // 当事人送达确认书
        otherFiles: { materialType: 'input', casePersonTypeName: { '0': '异议人', '1': '被申请人' } } // 其他材料
      },
      //  起诉（行政）
      'XZYS': {
        pleadings: { title: '起诉状',  materialClassification: '1', materialClassificationName: '起诉状', apply: '原告', applied: '被告', materialName(y,b) { return `${y}诉${b}的起诉状`  }, casePersonTypeName: { '0': '原告', '1': '被告' }   }, // 起诉状、申请书、国家赔偿申请书
        casePersonIdentifyFiles: { title: '起诉状',  materialClassification: { 0: '2', 1: '3', 2: '17', 3: '18', 4: '19' }, materialClassificationName: { 0: '原告', 1: '被告', 2: '第三人', 3: '原告代理人', 4: '证人' }, require: { 0: true, 1: false, 2: false, 3: true, 4: false } }, // 身份证明材料
        evidenceFiles: { show: false, casePersonTypeName: '原告' }, // 证据材料
        evidenceFilesOther: { show: true, casePersonTypeName: '原告' }, // 证据材料
        casePersonConfirmFiles: { materialClassification: '4', materialClassificationName: '送达地址确认书', casePersonTypeName: '原告' }, // 当事人送达确认书
        otherFiles: { materialType: 'select', casePersonTypeName: { '0': '原告', '1': '被告' } }, // 其他材料
        normativeFiles: { materialClassification: '22', materialClassificationName: '规范性文件', casePersonTypeName: { '0': '原告', '1': '被告' } }
      },
      //     自赔
      'FYXWPCYWJGZP': {
        pleadings: { title: '申请书',  materialClassification: '1', materialClassificationName: '申请书', apply: '赔偿请求人', applied: '赔偿义务机关', materialName(y,b) { return `${y}对${b}的申请书`  }, casePersonTypeName: { '0': '赔偿请求人', '1': '赔偿义务机关' }   }, // 起诉状、申请书、国家赔偿申请书
        casePersonIdentifyFiles: { title: '身份证明材料',  materialClassification: { 0: '2', 1: '3', 2: '17', 3: '18', 4: '19' }, materialClassificationName: { 0: '赔偿请求人', 1: '赔偿义务机关', 2: '', 3: '代理人', 4: '证人' }, require: { 0: true, 1: false, 2: false, 3: true, 4: false } }, // 身份证明材料
        evidenceFiles: { show: false, casePersonTypeName: '赔偿请求人' }, // 证据材料
        evidenceFilesOther: { show: true, casePersonTypeName: '赔偿请求人' }, // 证据材料
        casePersonConfirmFiles: { materialClassification: '4', materialClassificationName: '送达地址确认书', casePersonTypeName: '赔偿请求人' }, // 当事人送达确认书
        otherFiles: { materialType: 'input', casePersonTypeName: { '0': '赔偿请求人', '1': '赔偿义务机关' } } // 其他材料
      }
    },
    //  第四步---案件信息配置项
    caseBasic: {
      //  未定义默认不显示
      '': {
        display: [],
        requires: []

      },
      undefined: {
        display: [],
        requires: []

      },
      null: {
        display: [],
        requires: []

      },
      //  起诉
      'MSYS': {
        display: ['jurisdictionalBasis', 'prosecutionAmount', 'caims'],
        requires: ['prosecutionAmount', 'caims']
      },
      //  宣告死亡
      'XGSZSW': {
        display: ['evidences', 'announcedCaseNo', 'applyCondition'],
        requires: ['evidences']
      },
      // 行为能力认定
      'XWNLRD': {
        display: ['evidences', 'originalCaseNumber'],
        requires: ['evidences']
      },
      // 监护关系变更
      'JHGXBG':{
        display: ['evidences'],
        requires: ['evidences']
      },
      // 实现物品担保权
      'SXDBWQ':{
        display: ['evidences', 'amountDebtSecured'],
        requires: ['evidences']
      },
      // 调解协议司法确认
      'TJXYSFQR':{
        display: ['evidences', 'agreementDate ', 'mediationCaseNo'],
        requires: ['evidences']
      },
      // 监护人指定异议
      'JHRZDYY': {
        display: ['evidences'],
        requires: ['evidences']
      },
      //  起诉(行政)
      'XZYS':{
        display: ['evidences', 'normativeFilesCheck'],
        requires: ['evidences']
      },
      //   自赔
      'FYXWPCYWJGZP':{
        display: ['evidences', 'legalBasis', 'compensateForDamageApply'],
        requires: ['evidences', 'legalBasis']
      }
    },
    //  当事人信息修改来改变后方的材料及信息驱动配置
    updateByCasePerson: {
      '': { 0: [], 1: [], 2: [], 3: [], 4: [] },
      undefined: { 0: [], 1: [], 2: [], 3: [], 4: [] },
      null: { 0: [], 1: [], 2: [], 3: [], 4: [] },
      // 民事起诉
      'MSYS': {
        0: [ 'updatePleadingFiles', 'updateIdentifyFiles' ,'updateEvidenceFiles' ,'updateConfirmFiles' ,'updateOtherFiles', 'updateAgentJson', 'updateWitnessJson'],
        1: [ 'updatePleadingFiles', 'updateIdentifyFiles'],
        2: [ 'updateIdentifyFiles'],
        3: [ 'updateIdentifyFiles'],
        4: [ 'updateIdentifyFiles']
      },
      'XGSZSW': {
        0: [ 'updatePleadingFiles', 'updateIdentifyFiles' ,'updateEvidenceFilesOther' ,'updateConfirmFiles' ,'updateOtherFiles', 'updateAgentJson', 'updateWitnessJson', 'updateEvidences'],
        1: [ 'updatePleadingFiles', 'updateIdentifyFiles'],
        3: [ 'updateIdentifyFiles' ],
        4: [ 'updateIdentifyFiles']
      },
      'XWNLRD': {
        0: [ 'updatePleadingFiles', 'updateIdentifyFiles' ,'updateEvidenceFilesOther' ,'updateConfirmFiles' ,'updateOtherFiles', 'updateAgentJson', 'updateWitnessJson', 'updateEvidences'],
        1: [ 'updatePleadingFiles', 'updateIdentifyFiles'],
        3: [ 'updateIdentifyFiles' ],
        4: [ 'updateIdentifyFiles']
      },
      'JHGXBG': {
        0: [ 'updatePleadingFiles', 'updateIdentifyFiles' ,'updateEvidenceFilesOther' ,'updateConfirmFiles' ,'updateOtherFiles', 'updateAgentJson', 'updateWitnessJson', 'updateEvidences'],
        1: [ 'updatePleadingFiles', 'updateIdentifyFiles'],
        3: [ 'updateIdentifyFiles' ],
        4: [ 'updateIdentifyFiles']
      },
      'SXDBWQ': {
        0: [ 'updatePleadingFiles', 'updateIdentifyFiles' ,'updateEvidenceFilesOther' ,'updateConfirmFiles' ,'updateOtherFiles', 'updateAgentJson', 'updateWitnessJson', 'updateEvidences'],
        1: [ 'updatePleadingFiles', 'updateIdentifyFiles'],
        3: [ 'updateIdentifyFiles' ],
        4: [ 'updateIdentifyFiles']
      },
      'TJXYSFQR': {
        0: [ 'updatePleadingFiles', 'updateIdentifyFiles' ,'updateEvidenceFilesOther' ,'updateConfirmFiles' ,'updateOtherFiles', 'updateAgentJson', 'updateWitnessJson', 'updateEvidences'],
        1: [ 'updatePleadingFiles', 'updateIdentifyFiles'],
        3: [ 'updateIdentifyFiles' ],
        4: [ 'updateIdentifyFiles']
      },
      'JHRZDYY': {
        0: [ 'updatePleadingFiles', 'updateIdentifyFiles' ,'updateEvidenceFilesOther' ,'updateConfirmFiles' ,'updateOtherFiles', 'updateAgentJson', 'updateWitnessJson', 'updateEvidences'],
        1: [ 'updatePleadingFiles', 'updateIdentifyFiles'],
        3: [ 'updateIdentifyFiles' ],
        4: [ 'updateIdentifyFiles']
      },
      // 行政起诉
      'XZYS': {
        0: [ 'updatePleadingFiles', 'updateIdentifyFiles' ,'updateEvidenceFilesOther' ,'updateConfirmFiles' ,'updateOtherFiles', 'updateAgentJson', 'updateWitnessJson', 'updateEvidences', 'updateNormativeFiles'],
        1: [ 'updatePleadingFiles', 'updateIdentifyFiles'],
        2: [ 'updateIdentifyFiles'],
        3: [ 'updateIdentifyFiles' ],
        4: [ 'updateIdentifyFiles']
      },
      //  自赔
      'FYXWPCYWJGZP': {
        0: [ 'updatePleadingFiles', 'updateIdentifyFiles' ,'updateEvidenceFilesOther' ,'updateConfirmFiles' ,'updateOtherFiles', 'updateAgentJson', 'updateWitnessJson', 'updateEvidences'],
        1: [ 'updatePleadingFiles', 'updateIdentifyFiles'],
        3: [ 'updateIdentifyFiles' ],
        4: [ 'updateIdentifyFiles']
      }
    },
    caseFileRequires: {
      // 民事一审
      'MSYS': [
        function () { return this.form.pleadings.length ? true : '请添加起诉状'},
        function() {
          return !this.form.casePersonIdentifyFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人身份证明材料'
        },
        function () {
          return this.form.evidenceFiles.length ? true : '请添加证据材料'
        },
        function () {
          return !this.form.evidenceFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传证据材料清单'
        },
        function () {
          return this.form.evidenceFiles.filter(item => item.materialName === '证据材料' && item.ossInfoId).length ? true: '请添加证据材料'
        },
        function () {
          return !this.form.casePersonConfirmFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人送达地址确认书'
        }
      ],
      // 宣告死亡
      'XGSZSW': [
        function () { return this.form.pleadings.length ? true : '请添加申请书'},
        function() {
          return !this.form.casePersonIdentifyFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人身份证明材料'
        },
        function () {
          return !this.form.evidenceFilesOther.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的证据材料'
        },
        function () {
          return !this.form.casePersonConfirmFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人送达地址确认书'
        }
      ],
      // 行为能力认定
      'XWNLRD': [
        function () { return this.form.pleadings.length ? true : '请添加申请书'},
        function() {
          return !this.form.casePersonIdentifyFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人身份证明材料'
        },
        function () {
          return !this.form.evidenceFilesOther.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的证据材料'
        },
        function () {
          return !this.form.casePersonConfirmFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人送达地址确认书'
        }
      ],
      // 监护关系变更
      'JHGXBG': [
        function () { return this.form.pleadings.length ? true : '请添加申请书'},
        function() {
          return !this.form.casePersonIdentifyFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人身份证明材料'
        },
        function () {
          return !this.form.evidenceFilesOther.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的证据材料'
        },
        function () {
          return !this.form.casePersonConfirmFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人送达地址确认书'
        }
      ],
      // 实现物品担保权
      'SXDBWQ': [
        function () { return this.form.pleadings.length ? true : '请添加申请书'},
        function() {
          return !this.form.casePersonIdentifyFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人身份证明材料'
        },
        function () {
          return !this.form.evidenceFilesOther.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的证据材料'
        },
        function () {
          return !this.form.casePersonConfirmFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人送达地址确认书'
        }
      ],
      // 调解协议司法确认
      'TJXYSFQR': [
        function () { return this.form.pleadings.length ? true : '请添加申请书'},
        function() {
          return !this.form.casePersonIdentifyFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人身份证明材料'
        },
        function () {
          return !this.form.evidenceFilesOther.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的证据材料'
        },
        function () {
          return !this.form.casePersonConfirmFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人送达地址确认书'
        }
      ],
      // 监护人指定异议
      'JHRZDYY': [
        function () { return this.form.pleadings.length ? true : '请添加申请书'},
        function() {
          return !this.form.casePersonIdentifyFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人身份证明材料'
        },
        function () {
          return !this.form.evidenceFilesOther.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的证据材料'
        },
        function () {
          return !this.form.casePersonConfirmFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人送达地址确认书'
        }
      ],
      // 行政起诉
      'XZYS': [
        function () { return this.form.pleadings.length ? true : '请添加申请书'},
        function() {
          return !this.form.casePersonIdentifyFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人身份证明材料'
        },
        function () {
          return !this.form.evidenceFilesOther.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的证据材料'
        },
        function () {
          return !this.form.casePersonConfirmFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人送达地址确认书'
        },
        function () {
          return !this.form.normativeFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的规范性文件'
        }
      ],
      //  自赔
      'FYXWPCYWJGZP': [
        function () { return this.form.pleadings.length ? true : '请添加申请书'},
        function() {
          return !this.form.casePersonIdentifyFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人身份证明材料'
        },
        function () {
          return !this.form.evidenceFilesOther.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的证据材料'
        },
        function () {
          return !this.form.casePersonConfirmFiles.filter(item => item.isRequired && !item.ossInfoId).length ? true : '请上传必要的当事人送达地址确认书'
        }
      ]
    },
    caseStepValidate: {
      '': { 3: '', 4: '' },
      null: { 3: '', 4: '' },
      undefined: { 3: '', 4: '' },
      'MSYS': { 3: 'requiredFiles', 4: '' },
      'XGSZSW': { 3: '', 4: 'requiredFiles' },
      'XWNLRD': { 3: '', 4: 'requiredFiles' },
      'JHGXBG': { 3: '', 4: 'requiredFiles' },
      'SXDBWQ': { 3: '', 4: 'requiredFiles' },
      'TJXYSFQR': { 3: '', 4: 'requiredFiles' },
      'JHRZDYY': { 3: '', 4: 'requiredFiles' },
      'XZYS': { 3: '', 4: 'requiredFiles' },
      'FYXWPCYWJGZP': { 3: '', 4: 'requiredFiles' }
    },
  }
}
function getRandomNumber(length) {
  let string =  "abcdefghijklmnopqrstuvwxyz0123456789"
  let result = ''
  for(let i = 0; i < length; i++) {
    result += string[parseInt(Math.random() * string.length)];
  }
  return result;
}
