// 订阅中心抽象类
// 主要功能为对订阅源事件进行储存、移出、查询操作
// 特殊功能：执行订阅
class ObserveCenter {
    constructor() {
        this.store = {}
        //  创建订阅名称的空列表
        this.createEmptyTask = (name) => {
            this.store[name] = []
        }
        //  暴漏给子类的store（暂时没用）
        this.useStore = () => {
            return this.store
        }
        // 暴漏给子类的store查询 By name（暂时没用）
        this.useStoreByName = (name) => {
            return this.store[name]
        }
        // 加入订阅者到具名订阅列表中
        this.join = (name, content) => {
            if (!this.store[name]) {
                this.createEmptyTask(name)
            }
            this.store[name].push(content)
        }
        // 判断值是否被定义
        this.isDef = (value) => {
            return value !== undefined && value !== null
        }
        // 移除具名队列或具名队列中的某些订阅者
        this.remove = (name, query) => {
            if (!this.isDef(query)) {
                // query不存在时，整个删除
                delete this.store[name]
            } else if (typeof query === 'string' || typeof query === 'number') {
                //  利用id进行删除
                this.store[name] = this.store[name].filter(observe => {
                    if (Subscription.is(observe, 'Object')) {
                        // 已经用Object去判断 去除函数的情况 此处还报错，所以用类型断言
                        return observe.id !== query
                    } else { return true }
                })
            } else {
                // 利用相同指针函数进行删除
                this.store[name] = this.store[name].filter(observe => observe !== query)
            }
        }
        // 过滤执行
        this.$filterEmit = (name, query, ...args) => {
            const { store } = this
            if (!this.isDef(store[name])) {
                return
            }
            const tasks = store[name]
            const filterResult = store[name].reduce((init, c) => {
                // 批量查询
                if (Subscription.is(query, 'Array')) {
                    const item = query.findIndex(signle => {
                        if (typeof c === 'function') {
                            return signle === c
                        } else {
                            return signle === c.id
                        }
                    })
                    item === -1 ? init.n.push(c) : init.y.push(c)
                } else {
                    switch (typeof query) {
                        // 单个但寻
                        case 'function':
                            c === query ? init.y.push(c) : init.n.push(c)
                            break
                        default:
                            if (typeof c === 'function') {
                                init.n.push(c)
                            } else {
                                c.id === query ? init.y.push(c) : init.n.push(c)
                            }
                    }
                }
                return init
            }, { y: [], n: [] })
            const res = Subscription.Implement(filterResult.y, ...args)
            store[name] = filterResult.n.concat(res.filter(item => {
                return !item.__isDelete
            }).map(item => item.observe))
        }
        // 是否执行（同步、异步） -----> 执行 ------> 是否为一次性执行并是否移出
        this.$emit = (name, ...args) => {
            const { store } = this
            if (!this.isDef(store[name])) {
                return
            }
            const res = Subscription.Implement(store[name], ...args)
            store[name] = res.filter(item => {
                return !item.__isDelete
            }).map(item => item.observe)
        }
    }
}
ObserveCenter.is = (val, name) => {
    return Object.prototype.toString.call(val) === `[object ${name}]`
}
// 执行订阅
ObserveCenter.Implement = (tasks, ...args) => {
    return tasks.map(observe => {
        let __isDelete = false
        if (Subscription.is(observe, 'Object')) {
            //  若为config形式的observe
            // 拿到所有变量
            const { handler, once } = observe
            handler(...args)
            once && (() => { __isDelete = true })()
        } else if (Subscription.is(observe, 'Function')) {
            //  若为函数式observe
            observe(...args)
        }
        return { observe, __isDelete: __isDelete }
    })
}
// 个体订阅类
// 主要功能是对订阅中心进行订阅、取消订阅
class Subscription extends ObserveCenter {
    constructor() {
        super(...arguments)
        this.$on = (name, content) => {
            this.join(name, content)
        }
        this.$off = (name, query) => {
            this.remove(name, query)
        }
    }
}
