declare type vf = (...params: any[]) => void
declare interface Task {
    [props: string]: Array<vf>
}
// 任务中心抽象类
abstract class TaskCenter {
    private store: Task = {}
    private createTask = (name: string) :void =>  {
        this.store[name] = []
    }
    protected joinTask = (name: string, handler:vf): void => {
        if(!this.store[name]){
            this.createTask(name)
        }
        this.store[name].push(handler)

    }
    protected useTask(name: string): Array<vf> {
        return this.store[name]
    }

    protected removeTask(name: string, handler?: vf): void {
       if(!handler) {
          delete this.store[name] 
       } else {
           this.store[name] = this.store[name].filter(handle => handler !== handle)
           if(!this.store[name].length) delete this.store[name]
       }
    }

}
// 订阅类
class Subscription extends TaskCenter {
    public $on = (name: string, handler: vf) => {
      this.joinTask(name, handler)
    }

    public $emit = (name: string, ...params: any[]) => {
       let T: Array<vf> = this.useTask(name)
       if(!T || !T.length) return 
       T.forEach(handler => { handler(...params) })
    }

    public $off = (name: string, handler?: vf) => {
       if(!name || !this.useTask(name)) return
       this.removeTask(name, handler)
    }
}
