
var email = function(value) {
    return /^([a-zA-Z0-9_-])+@([a-zA-Z0-9_-])+(.[a-zA-Z0-9_-])+/.test(value + '')
}
/**
 * 验证手机格式
 */
var mobile = function(value) {
    return /^1[3-9]\d{9}$/.test(value + '')
}
// 邮政编码
var postCode = function (val) {
    return /^\d{6}$/.test(val + '')
}
/**
 * 验证URL格式
 */
function url(value) {
    return /http(s)?:\/\/([\w-]+\.)+[\w-]+(\/[\w-.\/?%&=]*)?/.test(value)
}
/**
 * 验证日期格式
 */
function date(value) {
    return !/Invalid|NaN/.test(new Date(value).toString())
}
/**
 * 验证ISO类型的日期格式
 */
function dateISO(value) {
    return /^\d{4}[\/\-](0?[1-9]|1[012])[\/\-](0?[1-9]|[12][0-9]|3[01])$/.test(value)
}
/**
 * 验证十进制数字
 */
function number(value) {
    return /^(?:-?\d+|-?\d{1,3}(?:,\d{3})+)?(?:\.\d+)?$/.test(value + '')
}
/**
 * 验证整数
 */
function digits(value) {
    return /^\d+$/.test(value + '')
}
/**
 * 验证身份证号码
 */
function idCard(value) {
    return {
        provinceCode: {
            11: '北京', 12: '天津', 13: '河北', 14: '山西', 15: '内蒙古', 21: '辽宁', 22: '吉林',
            23: '黑龙江 ', 31: '上海', 32: '江苏', 33: '浙江', 34: '安徽', 35: '福建', 36: '江西',
            37: '山东', 41: '河南', 42: '湖北 ', 43: '湖南', 44: '广东', 45: '广西', 46: '海南',
            50: '重庆', 51: '四川', 52: '贵州', 53: '云南', 54: '西藏 ', 61: '陕西', 62: '甘肃',
            63: '青海', 64: '宁夏', 65: '新疆', 71: '台湾', 81: '香港', 82: '澳门', 91: '国外 '
        },
        // 粗略验证是否为身份证号格式
        is_identity_number(val) {
            return /(^\d{15}$)|(^\d{17}(\d|X)$)/.test(val)
        },
        //  验证省区号
        validate_province_code(val) {
            const { provinceCode } = this
            return provinceCode[val.substr(0, 2)] !== undefined
        },
        // 验证出生日期是否符合规范
        validate_birthday(val) {
            const length = val.length
            let result
            let extra
            if (length === 15) {
                result = val.match(/^(\d{6})(\d{2})(\d{2})(\d{2})(\d{3})$/)
                extra = '19'
            } else if (length === 18) {
                result = val.match(/^(\d{6})(\d{4})(\d{2})(\d{2})(\d{3})([0-9]|X)$/)
                extra = ''
            } else { return false }
            const year = result[2]
            const month = result[3]
            const day = result[4]
            const birthday = new Date(`${extra + year}/${month}/${day}`)
            const years = new Date().getFullYear() - birthday.getFullYear()
            return years >= 3 && years <= 150
        },
        transferNormativeNumber(val) {
            if (val.length === 15) {
                const arrInt = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2]
                const arrCh = ['1', '0', 'X', '9', '8', '7', '6', '5', '4', '3', '2']
                let cardTemp = 0
                let i
                val = val.substr(0, 6) + '19' + val.substr(6, val.length - 6)
                for (i = 0; i < 17; i++) {
                    cardTemp += Number(val.substr(i, 1)) * arrInt[i]
                }
                val += arrCh[cardTemp % 11]
                return val
            }
            return val
        },
        validate_check_flag(val) {
            val = this.transferNormativeNumber(val)
            const arrInt = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2]
            const arrCh = ['1', '0', 'X', '9', '8', '7', '6', '5', '4', '3', '2']
            let cardTemp = 0
            let i
            for (i = 0; i < 17; i++) {
                cardTemp += Number(val.substr(i, 1)) * arrInt[i]
            }
            const valnum = arrCh[cardTemp % 11]
            return valnum === val.substr(17, 1)
        },
        validateIdentifyNumber(val) {
            const { is_identity_number, validate_province_code, validate_birthday, validate_check_flag } = this
            // 空不通过
            if (!val) {
                return false
            }
            // 粗略验证  不符合不通过
            if (!is_identity_number.call(this, val)) {
                return false
            }
            // 验证省号
            if (!validate_province_code.call(this, val)) {
                return false
            }
            // 验证出生日期
            if (!validate_birthday.call(this, val)) {
                return false
            }
            //  最后验证最后标志位
            return validate_check_flag.call(this, val)
        }
    }['validateIdentifyNumber'](value)

}
/**
 * 是否车牌号
 */
function carNo(value) {
    // 新能源车牌
    var xreg = /^[京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼使领A-Z]{1}[A-Z]{1}(([0-9]{5}[DF]$)|([DF][A-HJ-NP-Z0-9][0-9]{4}$))/
    // 旧车牌
    var creg = /^[京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼使领A-Z]{1}[A-Z]{1}[A-HJ-NP-Z0-9]{4}[A-HJ-NP-Z0-9挂学警港澳]{1}$/
    if (value.length === 7) {
        return creg.test(value)
    } else if (value.length === 8) {
        return xreg.test(value)
    } else {
        return false
    }
}
/**
 * 金额,只允许2位小数
 */
function amount(value) {
    // 金额，只允许保留两位小数
    return /^[1-9]\d*(,\d{3})*(\.\d{1,2})?$|^0\.\d{1,2}$/.test(value)
}
/**
 * 中文
 */
function chinese(value) {
    var reg = /^[\u4e00-\u9fa5]+$/gi
    return reg.test(value)
}
/**
 * 只能输入字母
 */
function letter(value) {
    return /^[a-zA-Z]*$/.test(value)
}
/**
 * 只能是字母或者数字
 */
function enOrNum(value) {
    // 英文或者数字
    var reg = /^[0-9a-zA-Z]*$/g
    return reg.test(value)
}
/**
 * 是否固定电话
 */
function landline(value) {
    var reg = /^\d{3,4}-\d{7,8}(-\d{3,4})?$/
    return reg.test(value + '')
}
/**
 * 判断是否为空
 */
function empty(value) {
    switch (typeof value) {
        case 'undefined':
            return true
        case 'string':
            if (value.replace(/(^[ \t\n\r]*)|([ \t\n\r]*$)/g, '').length === 0) { return true }
            break
        case 'boolean':
            if (!value) { return true }
            break
        case 'number':
            if (value === 0 || isNaN(value)) { return true }
            break
        case 'object':
            if (value === null || value.length === 0) { return true }
            for (var i in value) {
                return false
            }
            return true
    }
    return false
}
/**
 * 是否json字符串
 */
function jsonString(value) {
    if (typeof value === 'string') {
        try {
            var obj = JSON.parse(value)
            if (typeof obj === 'object' && obj) {
                return true
            } else {
                return false
            }
        } catch (e) {
            return false
        }
    }
    return false
}
/**
 * 是否数组
 */
function array(value) {
    if (typeof Array.isArray === 'function') {
        return Array.isArray(value)
    } else {
        return Object.prototype.toString.call(value) === '[object Array]'
    }
}
function object(value) {
    return Object.prototype.toString.call(value) === '[object Object]'
}
/**
 * 是否短信验证码
 */
function code(value) {
    return new RegExp('^\\d{4}$').test(value + '') || new RegExp('^\\d{6}$').test(value + '')
}
function isDef(value) {
    return value !== undefined && value !== null
}
function isPromise(value) {
    return isDef(value) && typeof value.then === 'function' && typeof value.catch === 'function'
}
//  2 到 16 位 中英文
function isRuleName(val) {
    return /^[\a-zA-Z\u4E00-\u9FA5\㛑]{2,16}$/.test(val)
}

const $validate = {
    isEmail: email, // 是否为邮箱
    isMobilePhoneNum: mobile, // 是否为手机号
    isHttp: url, // 是否为http(s) 合法网址
    isDate: date, // 是否为日期
    isDateISO: dateISO, // 是否为合法时间字符串 如：YYYY-MM-DD
    isNumber: number, // 是否为数字
    isInt: digits, // 是否为正整数
    isCarNumber: carNo, // 是否为合法车牌号
    isIdentify: idCard, // 是否为正确身份证号
    isChinese: chinese, // 是否为汉字
    isLetter: letter, // 是否为字母
    isNumberOrLetter: enOrNum, // 是否为数字或字母
    isPhoneNum: landline, // 是否为合法固定电话
    isEmpty: empty, // 是否为空
    isJsonString: jsonString, // 是否为json字符串
    isArray: array, // 是否为数组
    isObject: object, // 是否为对象
    isMessage: code, // 验证验证码
    isPromise, // 是否为Promise对象
    isPostCode: postCode,
    isRuleName
}
